# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/intent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from dialogflow_v2beta1.proto import (
    audio_config_pb2 as google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_audio__config__pb2,
)
from dialogflow_v2beta1.proto import (
    context_pb2 as google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_context__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/intent.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\013IntentProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n2google/cloud/dialogflow_v2beta1/proto/intent.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x38google/cloud/dialogflow_v2beta1/proto/audio_config.proto\x1a\x33google/cloud/dialogflow_v2beta1/proto/context.proto\x1a#google/longrunning/operations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto"\xfdN\n\x06Intent\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12P\n\rwebhook_state\x18\x06 \x01(\x0e\x32\x34.google.cloud.dialogflow.v2beta1.Intent.WebhookStateB\x03\xe0\x41\x01\x12\x15\n\x08priority\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01\x12\x18\n\x0bis_fallback\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01\x12\x19\n\nml_enabled\x18\x05 \x01(\x08\x42\x05\x18\x01\xe0\x41\x01\x12\x18\n\x0bml_disabled\x18\x13 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1c\n\x0f\x65nd_interaction\x18\x15 \x01(\x08\x42\x03\xe0\x41\x01\x12 \n\x13input_context_names\x18\x07 \x03(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x65vents\x18\x08 \x03(\tB\x03\xe0\x41\x01\x12U\n\x10training_phrases\x18\t \x03(\x0b\x32\x36.google.cloud.dialogflow.v2beta1.Intent.TrainingPhraseB\x03\xe0\x41\x01\x12\x13\n\x06\x61\x63tion\x18\n \x01(\tB\x03\xe0\x41\x01\x12\x46\n\x0foutput_contexts\x18\x0b \x03(\x0b\x32(.google.cloud.dialogflow.v2beta1.ContextB\x03\xe0\x41\x01\x12\x1b\n\x0ereset_contexts\x18\x0c \x01(\x08\x42\x03\xe0\x41\x01\x12J\n\nparameters\x18\r \x03(\x0b\x32\x31.google.cloud.dialogflow.v2beta1.Intent.ParameterB\x03\xe0\x41\x01\x12\x41\n\x08messages\x18\x0e \x03(\x0b\x32/.google.cloud.dialogflow.v2beta1.Intent.Message\x12\x61\n\x1a\x64\x65\x66\x61ult_response_platforms\x18\x0f \x03(\x0e\x32\x38.google.cloud.dialogflow.v2beta1.Intent.Message.PlatformB\x03\xe0\x41\x01\x12&\n\x19root_followup_intent_name\x18\x10 \x01(\tB\x03\xe0\x41\x03\x12(\n\x1bparent_followup_intent_name\x18\x11 \x01(\tB\x03\xe0\x41\x01\x12]\n\x14\x66ollowup_intent_info\x18\x12 \x03(\x0b\x32:.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfoB\x03\xe0\x41\x03\x1a\xec\x02\n\x0eTrainingPhrase\x12\x0c\n\x04name\x18\x01 \x01(\t\x12N\n\x04type\x18\x02 \x01(\x0e\x32;.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.TypeB\x03\xe0\x41\x02\x12O\n\x05parts\x18\x03 \x03(\x0b\x32;.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.PartB\x03\xe0\x41\x02\x12\x1e\n\x11times_added_count\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x1aN\n\x04Part\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x13\n\x0b\x65ntity_type\x18\x02 \x01(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t\x12\x14\n\x0cuser_defined\x18\x04 \x01(\x08";\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XAMPLE\x10\x01\x12\x10\n\x08TEMPLATE\x10\x02\x1a\x02\x08\x01\x1a\xac\x01\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x15\n\rdefault_value\x18\x04 \x01(\t\x12 \n\x18\x65ntity_type_display_name\x18\x05 \x01(\t\x12\x11\n\tmandatory\x18\x06 \x01(\x08\x12\x0f\n\x07prompts\x18\x07 \x03(\t\x12\x0f\n\x07is_list\x18\x08 \x01(\x08\x1a\xc2@\n\x07Message\x12\x44\n\x04text\x18\x01 \x01(\x0b\x32\x34.google.cloud.dialogflow.v2beta1.Intent.Message.TextH\x00\x12\x46\n\x05image\x18\x02 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.Intent.Message.ImageH\x00\x12U\n\rquick_replies\x18\x03 \x01(\x0b\x32<.google.cloud.dialogflow.v2beta1.Intent.Message.QuickRepliesH\x00\x12\x44\n\x04\x63\x61rd\x18\x04 \x01(\x0b\x32\x34.google.cloud.dialogflow.v2beta1.Intent.Message.CardH\x00\x12*\n\x07payload\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12[\n\x10simple_responses\x18\x07 \x01(\x0b\x32?.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponsesH\x00\x12O\n\nbasic_card\x18\x08 \x01(\x0b\x32\x39.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCardH\x00\x12R\n\x0bsuggestions\x18\t \x01(\x0b\x32;.google.cloud.dialogflow.v2beta1.Intent.Message.SuggestionsH\x00\x12`\n\x13link_out_suggestion\x18\n \x01(\x0b\x32\x41.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestionH\x00\x12Q\n\x0blist_select\x18\x0b \x01(\x0b\x32:.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelectH\x00\x12Y\n\x0f\x63\x61rousel_select\x18\x0c \x01(\x0b\x32>.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelectH\x00\x12\x62\n\x14telephony_play_audio\x18\r \x01(\x0b\x32\x42.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudioH\x00\x12p\n\x1btelephony_synthesize_speech\x18\x0e \x01(\x0b\x32I.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeechH\x00\x12h\n\x17telephony_transfer_call\x18\x0f \x01(\x0b\x32\x45.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCallH\x00\x12K\n\x08rbm_text\x18\x12 \x01(\x0b\x32\x37.google.cloud.dialogflow.v2beta1.Intent.Message.RbmTextH\x00\x12\x65\n\x18rbm_standalone_rich_card\x18\x13 \x01(\x0b\x32\x41.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCardH\x00\x12\x61\n\x16rbm_carousel_rich_card\x18\x14 \x01(\x0b\x32?.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCardH\x00\x12\x62\n\x14\x62rowse_carousel_card\x18\x16 \x01(\x0b\x32\x42.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCardH\x00\x12O\n\ntable_card\x18\x17 \x01(\x0b\x32\x39.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardH\x00\x12U\n\rmedia_content\x18\x18 \x01(\x0b\x32<.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContentH\x00\x12O\n\x08platform\x18\x06 \x01(\x0e\x32\x38.google.cloud.dialogflow.v2beta1.Intent.Message.PlatformB\x03\xe0\x41\x01\x1a\x14\n\x04Text\x12\x0c\n\x04text\x18\x01 \x03(\t\x1a\x36\n\x05Image\x12\x11\n\timage_uri\x18\x01 \x01(\t\x12\x1a\n\x12\x61\x63\x63\x65ssibility_text\x18\x02 \x01(\t\x1a\x34\n\x0cQuickReplies\x12\r\n\x05title\x18\x01 \x01(\t\x12\x15\n\rquick_replies\x18\x02 \x03(\t\x1a\xb2\x01\n\x04\x43\x61rd\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x11\n\timage_uri\x18\x03 \x01(\t\x12L\n\x07\x62uttons\x18\x04 \x03(\x0b\x32;.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button\x1a(\n\x06\x42utton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08postback\x18\x02 \x01(\t\x1aL\n\x0eSimpleResponse\x12\x16\n\x0etext_to_speech\x18\x01 \x01(\t\x12\x0c\n\x04ssml\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_text\x18\x03 \x01(\t\x1ak\n\x0fSimpleResponses\x12X\n\x10simple_responses\x18\x01 \x03(\x0b\x32>.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse\x1a\xfe\x02\n\tBasicCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x16\n\x0e\x66ormatted_text\x18\x03 \x01(\t\x12\x44\n\x05image\x18\x04 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.Intent.Message.Image\x12Q\n\x07\x62uttons\x18\x05 \x03(\x0b\x32@.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button\x1a\x9e\x01\n\x06\x42utton\x12\r\n\x05title\x18\x01 \x01(\t\x12g\n\x0fopen_uri_action\x18\x02 \x01(\x0b\x32N.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction\x1a\x1c\n\rOpenUriAction\x12\x0b\n\x03uri\x18\x01 \x01(\t\x1a\x1b\n\nSuggestion\x12\r\n\x05title\x18\x01 \x01(\t\x1a^\n\x0bSuggestions\x12O\n\x0bsuggestions\x18\x01 \x03(\x0b\x32:.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion\x1a:\n\x11LinkOutSuggestion\x12\x18\n\x10\x64\x65stination_name\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x1a\xc3\x02\n\nListSelect\x12\r\n\x05title\x18\x01 \x01(\t\x12N\n\x05items\x18\x02 \x03(\x0b\x32?.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item\x12\x15\n\x08subtitle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x1a\xbe\x01\n\x04Item\x12L\n\x04info\x18\x01 \x01(\x0b\x32>.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x44\n\x05image\x18\x04 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.Intent.Message.Image\x1a\xa5\x02\n\x0e\x43\x61rouselSelect\x12R\n\x05items\x18\x01 \x03(\x0b\x32\x43.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item\x1a\xbe\x01\n\x04Item\x12L\n\x04info\x18\x01 \x01(\x0b\x32>.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x44\n\x05image\x18\x04 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.Intent.Message.Image\x1a/\n\x0eSelectItemInfo\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08synonyms\x18\x02 \x03(\t\x1a\'\n\x12TelephonyPlayAudio\x12\x11\n\taudio_uri\x18\x01 \x01(\t\x1a\x45\n\x19TelephonySynthesizeSpeech\x12\x0e\n\x04text\x18\x01 \x01(\tH\x00\x12\x0e\n\x04ssml\x18\x02 \x01(\tH\x00\x42\x08\n\x06source\x1a-\n\x15TelephonyTransferCall\x12\x14\n\x0cphone_number\x18\x01 \x01(\t\x1an\n\x07RbmText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12U\n\x0erbm_suggestion\x18\x02 \x03(\x0b\x32=.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion\x1a\x87\x02\n\x0fRbmCarouselCard\x12]\n\ncard_width\x18\x01 \x01(\x0e\x32I.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.CardWidth\x12U\n\rcard_contents\x18\x02 \x03(\x0b\x32>.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent">\n\tCardWidth\x12\x1a\n\x16\x43\x41RD_WIDTH_UNSPECIFIED\x10\x00\x12\t\n\x05SMALL\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x1a\x82\x04\n\x11RbmStandaloneCard\x12k\n\x10\x63\x61rd_orientation\x18\x01 \x01(\x0e\x32Q.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.CardOrientation\x12|\n\x19thumbnail_image_alignment\x18\x02 \x01(\x0e\x32Y.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.ThumbnailImageAlignment\x12T\n\x0c\x63\x61rd_content\x18\x03 \x01(\x0b\x32>.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent"Q\n\x0f\x43\x61rdOrientation\x12 \n\x1c\x43\x41RD_ORIENTATION_UNSPECIFIED\x10\x00\x12\x0e\n\nHORIZONTAL\x10\x01\x12\x0c\n\x08VERTICAL\x10\x02"Y\n\x17ThumbnailImageAlignment\x12)\n%THUMBNAIL_IMAGE_ALIGNMENT_UNSPECIFIED\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x1a\xb9\x03\n\x0eRbmCardContent\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12V\n\x05media\x18\x03 \x01(\x0b\x32G.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia\x12R\n\x0bsuggestions\x18\x04 \x03(\x0b\x32=.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion\x1a\xd6\x01\n\x08RbmMedia\x12\x10\n\x08\x66ile_uri\x18\x01 \x01(\t\x12\x15\n\rthumbnail_uri\x18\x02 \x01(\t\x12^\n\x06height\x18\x03 \x01(\x0e\x32N.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.Height"A\n\x06Height\x12\x16\n\x12HEIGHT_UNSPECIFIED\x10\x00\x12\t\n\x05SHORT\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x08\n\x04TALL\x10\x03\x1a\xc7\x01\n\rRbmSuggestion\x12R\n\x05reply\x18\x01 \x01(\x0b\x32\x41.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReplyH\x00\x12T\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x42.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedActionH\x00\x42\x0c\n\nsuggestion\x1a\x38\n\x11RbmSuggestedReply\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\rpostback_data\x18\x02 \x01(\t\x1a\x9b\x04\n\x12RbmSuggestedAction\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\rpostback_data\x18\x02 \x01(\t\x12i\n\x04\x64ial\x18\x03 \x01(\x0b\x32Y.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDialH\x00\x12p\n\x08open_url\x18\x04 \x01(\x0b\x32\\.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUriH\x00\x12|\n\x0eshare_location\x18\x05 \x01(\x0b\x32\x62.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocationH\x00\x1a.\n\x16RbmSuggestedActionDial\x12\x14\n\x0cphone_number\x18\x01 \x01(\t\x1a(\n\x19RbmSuggestedActionOpenUri\x12\x0b\n\x03uri\x18\x01 \x01(\t\x1a!\n\x1fRbmSuggestedActionShareLocationB\x08\n\x06\x61\x63tion\x1a\x8e\x04\n\x0cMediaContent\x12\x62\n\nmedia_type\x18\x01 \x01(\x0e\x32N.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaType\x12g\n\rmedia_objects\x18\x02 \x03(\x0b\x32P.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject\x1a\xeb\x01\n\x13ResponseMediaObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\x0blarge_image\x18\x03 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.Intent.Message.ImageH\x00\x12\x45\n\x04icon\x18\x04 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.Intent.Message.ImageH\x00\x12\x13\n\x0b\x63ontent_url\x18\x05 \x01(\tB\x07\n\x05image"C\n\x11ResponseMediaType\x12#\n\x1fRESPONSE_MEDIA_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x41UDIO\x10\x01\x1a\x80\x07\n\x12\x42rowseCarouselCard\x12h\n\x05items\x18\x01 \x03(\x0b\x32Y.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem\x12u\n\x15image_display_options\x18\x02 \x01(\x0e\x32V.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.ImageDisplayOptions\x1a\x90\x04\n\x16\x42rowseCarouselCardItem\x12\x80\x01\n\x0fopen_uri_action\x18\x01 \x01(\x0b\x32g.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x44\n\x05image\x18\x04 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.Intent.Message.Image\x12\x0e\n\x06\x66ooter\x18\x05 \x01(\t\x1a\xf8\x01\n\rOpenUrlAction\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x8a\x01\n\rurl_type_hint\x18\x03 \x01(\x0e\x32s.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint"M\n\x0bUrlTypeHint\x12\x1d\n\x19URL_TYPE_HINT_UNSPECIFIED\x10\x00\x12\x0e\n\nAMP_ACTION\x10\x01\x12\x0f\n\x0b\x41MP_CONTENT\x10\x02"v\n\x13ImageDisplayOptions\x12%\n!IMAGE_DISPLAY_OPTIONS_UNSPECIFIED\x10\x00\x12\x08\n\x04GRAY\x10\x01\x12\t\n\x05WHITE\x10\x02\x12\x0b\n\x07\x43ROPPED\x10\x03\x12\x16\n\x12\x42LURRED_BACKGROUND\x10\x04\x1a\xee\x02\n\tTableCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x44\n\x05image\x18\x03 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.Intent.Message.Image\x12[\n\x11\x63olumn_properties\x18\x04 \x03(\x0b\x32@.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties\x12J\n\x04rows\x18\x05 \x03(\x0b\x32<.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow\x12Q\n\x07\x62uttons\x18\x06 \x03(\x0b\x32@.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button\x1a\xfa\x01\n\x10\x43olumnProperties\x12\x0e\n\x06header\x18\x01 \x01(\t\x12r\n\x14horizontal_alignment\x18\x02 \x01(\x0e\x32T.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.HorizontalAlignment"b\n\x13HorizontalAlignment\x12$\n HORIZONTAL_ALIGNMENT_UNSPECIFIED\x10\x00\x12\x0b\n\x07LEADING\x10\x01\x12\n\n\x06\x43\x45NTER\x10\x02\x12\x0c\n\x08TRAILING\x10\x03\x1as\n\x0cTableCardRow\x12L\n\x05\x63\x65lls\x18\x01 \x03(\x0b\x32=.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell\x12\x15\n\rdivider_after\x18\x02 \x01(\x08\x1a\x1d\n\rTableCardCell\x12\x0c\n\x04text\x18\x01 \x01(\t"\xaf\x01\n\x08Platform\x12\x18\n\x14PLATFORM_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x01\x12\t\n\x05SLACK\x10\x02\x12\x0c\n\x08TELEGRAM\x10\x03\x12\x07\n\x03KIK\x10\x04\x12\t\n\x05SKYPE\x10\x05\x12\x08\n\x04LINE\x10\x06\x12\t\n\x05VIBER\x10\x07\x12\x15\n\x11\x41\x43TIONS_ON_GOOGLE\x10\x08\x12\r\n\tTELEPHONY\x10\n\x12\x13\n\x0fGOOGLE_HANGOUTS\x10\x0b\x42\t\n\x07message\x1aW\n\x12\x46ollowupIntentInfo\x12\x1c\n\x14\x66ollowup_intent_name\x18\x01 \x01(\t\x12#\n\x1bparent_followup_intent_name\x18\x02 \x01(\t"t\n\x0cWebhookState\x12\x1d\n\x19WEBHOOK_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15WEBHOOK_STATE_ENABLED\x10\x01\x12*\n&WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING\x10\x02:\x91\x01\xea\x41\x8d\x01\n dialogflow.googleapis.com/Intent\x12)projects/{project}/agent/intents/{intent}\x12>projects/{project}/locations/{location}/agent/intents/{intent}"\xd3\x01\n\x12ListIntentsRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41"\x12 dialogflow.googleapis.com/Intent\x12\x1a\n\rlanguage_code\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12@\n\x0bintent_view\x18\x03 \x01(\x0e\x32+.google.cloud.dialogflow.v2beta1.IntentView\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x05 \x01(\t"h\n\x13ListIntentsResponse\x12\x38\n\x07intents\x18\x01 \x03(\x0b\x32\'.google.cloud.dialogflow.v2beta1.Intent\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\xa8\x01\n\x10GetIntentRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41"\n dialogflow.googleapis.com/Intent\x12\x1a\n\rlanguage_code\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12@\n\x0bintent_view\x18\x03 \x01(\x0e\x32+.google.cloud.dialogflow.v2beta1.IntentView"\xeb\x01\n\x13\x43reateIntentRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41"\x12 dialogflow.googleapis.com/Intent\x12<\n\x06intent\x18\x02 \x01(\x0b\x32\'.google.cloud.dialogflow.v2beta1.IntentB\x03\xe0\x41\x02\x12\x1a\n\rlanguage_code\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12@\n\x0bintent_view\x18\x04 \x01(\x0e\x32+.google.cloud.dialogflow.v2beta1.IntentView"\xe2\x01\n\x13UpdateIntentRequest\x12<\n\x06intent\x18\x01 \x01(\x0b\x32\'.google.cloud.dialogflow.v2beta1.IntentB\x03\xe0\x41\x02\x12\x1a\n\rlanguage_code\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12@\n\x0bintent_view\x18\x04 \x01(\x0e\x32+.google.cloud.dialogflow.v2beta1.IntentView"M\n\x13\x44\x65leteIntentRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41"\n dialogflow.googleapis.com/Intent"\xdd\x02\n\x19\x42\x61tchUpdateIntentsRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41"\x12 dialogflow.googleapis.com/Intent\x12\x1a\n\x10intent_batch_uri\x18\x02 \x01(\tH\x00\x12K\n\x13intent_batch_inline\x18\x03 \x01(\x0b\x32,.google.cloud.dialogflow.v2beta1.IntentBatchH\x00\x12\x1a\n\rlanguage_code\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12/\n\x0bupdate_mask\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12@\n\x0bintent_view\x18\x06 \x01(\x0e\x32+.google.cloud.dialogflow.v2beta1.IntentViewB\x0e\n\x0cintent_batch"V\n\x1a\x42\x61tchUpdateIntentsResponse\x12\x38\n\x07intents\x18\x01 \x03(\x0b\x32\'.google.cloud.dialogflow.v2beta1.Intent"\x94\x01\n\x19\x42\x61tchDeleteIntentsRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41"\x12 dialogflow.googleapis.com/Intent\x12=\n\x07intents\x18\x02 \x03(\x0b\x32\'.google.cloud.dialogflow.v2beta1.IntentB\x03\xe0\x41\x02"G\n\x0bIntentBatch\x12\x38\n\x07intents\x18\x01 \x03(\x0b\x32\'.google.cloud.dialogflow.v2beta1.Intent*?\n\nIntentView\x12\x1b\n\x17INTENT_VIEW_UNSPECIFIED\x10\x00\x12\x14\n\x10INTENT_VIEW_FULL\x10\x01\x32\xe3\x10\n\x07Intents\x12\x87\x02\n\x0bListIntents\x12\x33.google.cloud.dialogflow.v2beta1.ListIntentsRequest\x1a\x34.google.cloud.dialogflow.v2beta1.ListIntentsResponse"\x8c\x01\x82\xd3\xe4\x93\x02\x66\x12*/v2beta1/{parent=projects/*/agent}/intentsZ8\x12\x36/v2beta1/{parent=projects/*/locations/*/agent}/intents\xda\x41\x06parent\xda\x41\x14parent,language_code\x12\xf2\x01\n\tGetIntent\x12\x31.google.cloud.dialogflow.v2beta1.GetIntentRequest\x1a\'.google.cloud.dialogflow.v2beta1.Intent"\x88\x01\x82\xd3\xe4\x93\x02\x66\x12*/v2beta1/{name=projects/*/agent/intents/*}Z8\x12\x36/v2beta1/{name=projects/*/locations/*/agent/intents/*}\xda\x41\x04name\xda\x41\x12name,language_code\x12\x9a\x02\n\x0c\x43reateIntent\x12\x34.google.cloud.dialogflow.v2beta1.CreateIntentRequest\x1a\'.google.cloud.dialogflow.v2beta1.Intent"\xaa\x01\x82\xd3\xe4\x93\x02v"*/v2beta1/{parent=projects/*/agent}/intents:\x06intentZ@"6/v2beta1/{parent=projects/*/locations/*/agent}/intents:\x06intent\xda\x41\rparent,intent\xda\x41\x1bparent,intent,language_code\x12\xd3\x02\n\x0cUpdateIntent\x12\x34.google.cloud.dialogflow.v2beta1.UpdateIntentRequest\x1a\'.google.cloud.dialogflow.v2beta1.Intent"\xe3\x01\x82\xd3\xe4\x93\x02\x84\x01\x32\x31/v2beta1/{intent.name=projects/*/agent/intents/*}:\x06intentZG2=/v2beta1/{intent.name=projects/*/locations/*/agent/intents/*}:\x06intent\xda\x41\x12intent,update_mask\xda\x41\x06intent\xda\x41\x14intent,language_code\xda\x41 intent,language_code,update_mask\x12\xd1\x01\n\x0c\x44\x65leteIntent\x12\x34.google.cloud.dialogflow.v2beta1.DeleteIntentRequest\x1a\x16.google.protobuf.Empty"s\x82\xd3\xe4\x93\x02\x66**/v2beta1/{name=projects/*/agent/intents/*}Z8*6/v2beta1/{name=projects/*/locations/*/agent/intents/*}\xda\x41\x04name\x12\xd4\x02\n\x12\x42\x61tchUpdateIntents\x12:.google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest\x1a\x1d.google.longrunning.Operation"\xe2\x01\x82\xd3\xe4\x93\x02\x84\x01"6/v2beta1/{parent=projects/*/agent}/intents:batchUpdate:\x01*ZG"B/v2beta1/{parent=projects/*/locations/*/agent}/intents:batchUpdate:\x01*\xca\x41T\n:google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse\x12\x16google.protobuf.Struct\x12\xc0\x02\n\x12\x42\x61tchDeleteIntents\x12:.google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest\x1a\x1d.google.longrunning.Operation"\xce\x01\x82\xd3\xe4\x93\x02\x84\x01"6/v2beta1/{parent=projects/*/agent}/intents:batchDelete:\x01*ZG"B/v2beta1/{parent=projects/*/locations/*/agent}/intents:batchDelete:\x01*\xda\x41\x0eparent,intents\xca\x41/\n\x15google.protobuf.Empty\x12\x16google.protobuf.Struct\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xa9\x01\n#com.google.cloud.dialogflow.v2beta1B\x0bIntentProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_audio__config__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_context__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
    ],
)

_INTENTVIEW = _descriptor.EnumDescriptor(
    name="IntentView",
    full_name="google.cloud.dialogflow.v2beta1.IntentView",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="INTENT_VIEW_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="INTENT_VIEW_FULL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=12288,
    serialized_end=12351,
)
_sym_db.RegisterEnumDescriptor(_INTENTVIEW)

IntentView = enum_type_wrapper.EnumTypeWrapper(_INTENTVIEW)
INTENT_VIEW_UNSPECIFIED = 0
INTENT_VIEW_FULL = 1


_INTENT_TRAININGPHRASE_TYPE = _descriptor.EnumDescriptor(
    name="Type",
    full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Type",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="EXAMPLE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TEMPLATE",
            index=2,
            number=2,
            serialized_options=b"\010\001",
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1735,
    serialized_end=1794,
)
_sym_db.RegisterEnumDescriptor(_INTENT_TRAININGPHRASE_TYPE)

_INTENT_MESSAGE_RBMCAROUSELCARD_CARDWIDTH = _descriptor.EnumDescriptor(
    name="CardWidth",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.CardWidth",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CARD_WIDTH_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SMALL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MEDIUM",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6018,
    serialized_end=6080,
)
_sym_db.RegisterEnumDescriptor(_INTENT_MESSAGE_RBMCAROUSELCARD_CARDWIDTH)

_INTENT_MESSAGE_RBMSTANDALONECARD_CARDORIENTATION = _descriptor.EnumDescriptor(
    name="CardOrientation",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.CardOrientation",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CARD_ORIENTATION_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="HORIZONTAL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="VERTICAL",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6425,
    serialized_end=6506,
)
_sym_db.RegisterEnumDescriptor(_INTENT_MESSAGE_RBMSTANDALONECARD_CARDORIENTATION)

_INTENT_MESSAGE_RBMSTANDALONECARD_THUMBNAILIMAGEALIGNMENT = _descriptor.EnumDescriptor(
    name="ThumbnailImageAlignment",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.ThumbnailImageAlignment",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="THUMBNAIL_IMAGE_ALIGNMENT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LEFT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RIGHT",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6508,
    serialized_end=6597,
)
_sym_db.RegisterEnumDescriptor(
    _INTENT_MESSAGE_RBMSTANDALONECARD_THUMBNAILIMAGEALIGNMENT
)

_INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA_HEIGHT = _descriptor.EnumDescriptor(
    name="Height",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.Height",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="HEIGHT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SHORT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MEDIUM",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TALL",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6976,
    serialized_end=7041,
)
_sym_db.RegisterEnumDescriptor(_INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA_HEIGHT)

_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIATYPE = _descriptor.EnumDescriptor(
    name="ResponseMediaType",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="RESPONSE_MEDIA_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUDIO",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=8305,
    serialized_end=8372,
)
_sym_db.RegisterEnumDescriptor(_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIATYPE)

_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION_URLTYPEHINT = _descriptor.EnumDescriptor(
    name="UrlTypeHint",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="URL_TYPE_HINT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AMP_ACTION",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AMP_CONTENT",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=9074,
    serialized_end=9151,
)
_sym_db.RegisterEnumDescriptor(
    _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION_URLTYPEHINT
)

_INTENT_MESSAGE_BROWSECAROUSELCARD_IMAGEDISPLAYOPTIONS = _descriptor.EnumDescriptor(
    name="ImageDisplayOptions",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.ImageDisplayOptions",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="IMAGE_DISPLAY_OPTIONS_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GRAY",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WHITE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CROPPED",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BLURRED_BACKGROUND",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=9153,
    serialized_end=9271,
)
_sym_db.RegisterEnumDescriptor(_INTENT_MESSAGE_BROWSECAROUSELCARD_IMAGEDISPLAYOPTIONS)

_INTENT_MESSAGE_COLUMNPROPERTIES_HORIZONTALALIGNMENT = _descriptor.EnumDescriptor(
    name="HorizontalAlignment",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.HorizontalAlignment",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="HORIZONTAL_ALIGNMENT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LEADING",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CENTER",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TRAILING",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=9795,
    serialized_end=9893,
)
_sym_db.RegisterEnumDescriptor(_INTENT_MESSAGE_COLUMNPROPERTIES_HORIZONTALALIGNMENT)

_INTENT_MESSAGE_PLATFORM = _descriptor.EnumDescriptor(
    name="Platform",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Platform",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="PLATFORM_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FACEBOOK",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SLACK",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TELEGRAM",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="KIK",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SKYPE",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LINE",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="VIBER",
            index=7,
            number=7,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ACTIONS_ON_GOOGLE",
            index=8,
            number=8,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TELEPHONY",
            index=9,
            number=10,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GOOGLE_HANGOUTS",
            index=10,
            number=11,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=10044,
    serialized_end=10219,
)
_sym_db.RegisterEnumDescriptor(_INTENT_MESSAGE_PLATFORM)

_INTENT_WEBHOOKSTATE = _descriptor.EnumDescriptor(
    name="WebhookState",
    full_name="google.cloud.dialogflow.v2beta1.Intent.WebhookState",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="WEBHOOK_STATE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WEBHOOK_STATE_ENABLED",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=10321,
    serialized_end=10437,
)
_sym_db.RegisterEnumDescriptor(_INTENT_WEBHOOKSTATE)


_INTENT_TRAININGPHRASE_PART = _descriptor.Descriptor(
    name="Part",
    full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_type",
            full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.entity_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="alias",
            full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.alias",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="user_defined",
            full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.user_defined",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1655,
    serialized_end=1733,
)

_INTENT_TRAININGPHRASE = _descriptor.Descriptor(
    name="TrainingPhrase",
    full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.type",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parts",
            full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.parts",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="times_added_count",
            full_name="google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.times_added_count",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_INTENT_TRAININGPHRASE_PART],
    enum_types=[_INTENT_TRAININGPHRASE_TYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1430,
    serialized_end=1794,
)

_INTENT_PARAMETER = _descriptor.Descriptor(
    name="Parameter",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter.value",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default_value",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter.default_value",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_type_display_name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter.entity_type_display_name",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mandatory",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter.mandatory",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="prompts",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter.prompts",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="is_list",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Parameter.is_list",
            index=7,
            number=8,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1797,
    serialized_end=1969,
)

_INTENT_MESSAGE_TEXT = _descriptor.Descriptor(
    name="Text",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Text",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Text.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3804,
    serialized_end=3824,
)

_INTENT_MESSAGE_IMAGE = _descriptor.Descriptor(
    name="Image",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Image",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="image_uri",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Image.image_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="accessibility_text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Image.accessibility_text",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3826,
    serialized_end=3880,
)

_INTENT_MESSAGE_QUICKREPLIES = _descriptor.Descriptor(
    name="QuickReplies",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="quick_replies",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.quick_replies",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3882,
    serialized_end=3934,
)

_INTENT_MESSAGE_CARD_BUTTON = _descriptor.Descriptor(
    name="Button",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="postback",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.postback",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4075,
    serialized_end=4115,
)

_INTENT_MESSAGE_CARD = _descriptor.Descriptor(
    name="Card",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Card",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Card.title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="subtitle",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Card.subtitle",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image_uri",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Card.image_uri",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="buttons",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Card.buttons",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_INTENT_MESSAGE_CARD_BUTTON],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3937,
    serialized_end=4115,
)

_INTENT_MESSAGE_SIMPLERESPONSE = _descriptor.Descriptor(
    name="SimpleResponse",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text_to_speech",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.text_to_speech",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ssml",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.ssml",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.display_text",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4117,
    serialized_end=4193,
)

_INTENT_MESSAGE_SIMPLERESPONSES = _descriptor.Descriptor(
    name="SimpleResponses",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="simple_responses",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.simple_responses",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4195,
    serialized_end=4302,
)

_INTENT_MESSAGE_BASICCARD_BUTTON_OPENURIACTION = _descriptor.Descriptor(
    name="OpenUriAction",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4659,
    serialized_end=4687,
)

_INTENT_MESSAGE_BASICCARD_BUTTON = _descriptor.Descriptor(
    name="Button",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="open_uri_action",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.open_uri_action",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_INTENT_MESSAGE_BASICCARD_BUTTON_OPENURIACTION],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4529,
    serialized_end=4687,
)

_INTENT_MESSAGE_BASICCARD = _descriptor.Descriptor(
    name="BasicCard",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="subtitle",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.subtitle",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="formatted_text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.formatted_text",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.image",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="buttons",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.buttons",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_INTENT_MESSAGE_BASICCARD_BUTTON],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4305,
    serialized_end=4687,
)

_INTENT_MESSAGE_SUGGESTION = _descriptor.Descriptor(
    name="Suggestion",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion.title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4689,
    serialized_end=4716,
)

_INTENT_MESSAGE_SUGGESTIONS = _descriptor.Descriptor(
    name="Suggestions",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="suggestions",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.suggestions",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4718,
    serialized_end=4812,
)

_INTENT_MESSAGE_LINKOUTSUGGESTION = _descriptor.Descriptor(
    name="LinkOutSuggestion",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="destination_name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.destination_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4814,
    serialized_end=4872,
)

_INTENT_MESSAGE_LISTSELECT_ITEM = _descriptor.Descriptor(
    name="Item",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="info",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.info",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.title",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.image",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5008,
    serialized_end=5198,
)

_INTENT_MESSAGE_LISTSELECT = _descriptor.Descriptor(
    name="ListSelect",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="items",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.items",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="subtitle",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.subtitle",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_INTENT_MESSAGE_LISTSELECT_ITEM],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4875,
    serialized_end=5198,
)

_INTENT_MESSAGE_CAROUSELSELECT_ITEM = _descriptor.Descriptor(
    name="Item",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="info",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.info",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.title",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.image",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5008,
    serialized_end=5198,
)

_INTENT_MESSAGE_CAROUSELSELECT = _descriptor.Descriptor(
    name="CarouselSelect",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="items",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.items",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[_INTENT_MESSAGE_CAROUSELSELECT_ITEM],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5201,
    serialized_end=5494,
)

_INTENT_MESSAGE_SELECTITEMINFO = _descriptor.Descriptor(
    name="SelectItemInfo",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="synonyms",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.synonyms",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5496,
    serialized_end=5543,
)

_INTENT_MESSAGE_TELEPHONYPLAYAUDIO = _descriptor.Descriptor(
    name="TelephonyPlayAudio",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="audio_uri",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio.audio_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5545,
    serialized_end=5584,
)

_INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH = _descriptor.Descriptor(
    name="TelephonySynthesizeSpeech",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ssml",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.ssml",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="source",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.source",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=5586,
    serialized_end=5655,
)

_INTENT_MESSAGE_TELEPHONYTRANSFERCALL = _descriptor.Descriptor(
    name="TelephonyTransferCall",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="phone_number",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall.phone_number",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5657,
    serialized_end=5702,
)

_INTENT_MESSAGE_RBMTEXT = _descriptor.Descriptor(
    name="RbmText",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmText",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="rbm_suggestion",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.rbm_suggestion",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5704,
    serialized_end=5814,
)

_INTENT_MESSAGE_RBMCAROUSELCARD = _descriptor.Descriptor(
    name="RbmCarouselCard",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="card_width",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.card_width",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="card_contents",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.card_contents",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_INTENT_MESSAGE_RBMCAROUSELCARD_CARDWIDTH],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5817,
    serialized_end=6080,
)

_INTENT_MESSAGE_RBMSTANDALONECARD = _descriptor.Descriptor(
    name="RbmStandaloneCard",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="card_orientation",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.card_orientation",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="thumbnail_image_alignment",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.thumbnail_image_alignment",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="card_content",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.card_content",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _INTENT_MESSAGE_RBMSTANDALONECARD_CARDORIENTATION,
        _INTENT_MESSAGE_RBMSTANDALONECARD_THUMBNAILIMAGEALIGNMENT,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6083,
    serialized_end=6597,
)

_INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA = _descriptor.Descriptor(
    name="RbmMedia",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="file_uri",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.file_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="thumbnail_uri",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.thumbnail_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="height",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.height",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA_HEIGHT],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6827,
    serialized_end=7041,
)

_INTENT_MESSAGE_RBMCARDCONTENT = _descriptor.Descriptor(
    name="RbmCardContent",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="media",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.media",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="suggestions",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.suggestions",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6600,
    serialized_end=7041,
)

_INTENT_MESSAGE_RBMSUGGESTION = _descriptor.Descriptor(
    name="RbmSuggestion",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="reply",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.reply",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="action",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.action",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="suggestion",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.suggestion",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=7044,
    serialized_end=7243,
)

_INTENT_MESSAGE_RBMSUGGESTEDREPLY = _descriptor.Descriptor(
    name="RbmSuggestedReply",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="postback_data",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.postback_data",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7245,
    serialized_end=7301,
)

_INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONDIAL = _descriptor.Descriptor(
    name="RbmSuggestedActionDial",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="phone_number",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial.phone_number",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7710,
    serialized_end=7756,
)

_INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONOPENURI = _descriptor.Descriptor(
    name="RbmSuggestedActionOpenUri",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7758,
    serialized_end=7798,
)

_INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONSHARELOCATION = _descriptor.Descriptor(
    name="RbmSuggestedActionShareLocation",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7800,
    serialized_end=7833,
)

_INTENT_MESSAGE_RBMSUGGESTEDACTION = _descriptor.Descriptor(
    name="RbmSuggestedAction",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="postback_data",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.postback_data",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dial",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.dial",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="open_url",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.open_url",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="share_location",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.share_location",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONDIAL,
        _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONOPENURI,
        _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONSHARELOCATION,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="action",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.action",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=7304,
    serialized_end=7843,
)

_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT = _descriptor.Descriptor(
    name="ResponseMediaObject",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="large_image",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.large_image",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="icon",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.icon",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content_url",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.content_url",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="image",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.image",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=8068,
    serialized_end=8303,
)

_INTENT_MESSAGE_MEDIACONTENT = _descriptor.Descriptor(
    name="MediaContent",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="media_type",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.media_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="media_objects",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.media_objects",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT],
    enum_types=[_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIATYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=7846,
    serialized_end=8372,
)

_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION = _descriptor.Descriptor(
    name="OpenUrlAction",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="url",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.url",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="url_type_hint",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.url_type_hint",
            index=1,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION_URLTYPEHINT
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8903,
    serialized_end=9151,
)

_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM = _descriptor.Descriptor(
    name="BrowseCarouselCardItem",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="open_uri_action",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.open_uri_action",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.title",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.image",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="footer",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.footer",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8623,
    serialized_end=9151,
)

_INTENT_MESSAGE_BROWSECAROUSELCARD = _descriptor.Descriptor(
    name="BrowseCarouselCard",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="items",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.items",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image_display_options",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.image_display_options",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM],
    enum_types=[_INTENT_MESSAGE_BROWSECAROUSELCARD_IMAGEDISPLAYOPTIONS],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=8375,
    serialized_end=9271,
)

_INTENT_MESSAGE_TABLECARD = _descriptor.Descriptor(
    name="TableCard",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCard",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.title",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="subtitle",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.subtitle",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.image",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="column_properties",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.column_properties",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="rows",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.rows",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="buttons",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.buttons",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=9274,
    serialized_end=9640,
)

_INTENT_MESSAGE_COLUMNPROPERTIES = _descriptor.Descriptor(
    name="ColumnProperties",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="header",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.header",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="horizontal_alignment",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.horizontal_alignment",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_INTENT_MESSAGE_COLUMNPROPERTIES_HORIZONTALALIGNMENT],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=9643,
    serialized_end=9893,
)

_INTENT_MESSAGE_TABLECARDROW = _descriptor.Descriptor(
    name="TableCardRow",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="cells",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.cells",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="divider_after",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.divider_after",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=9895,
    serialized_end=10010,
)

_INTENT_MESSAGE_TABLECARDCELL = _descriptor.Descriptor(
    name="TableCardCell",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell.text",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10012,
    serialized_end=10041,
)

_INTENT_MESSAGE = _descriptor.Descriptor(
    name="Message",
    full_name="google.cloud.dialogflow.v2beta1.Intent.Message",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.text",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.image",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="quick_replies",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.quick_replies",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="card",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.card",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.payload",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="simple_responses",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.simple_responses",
            index=5,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="basic_card",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.basic_card",
            index=6,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="suggestions",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.suggestions",
            index=7,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="link_out_suggestion",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.link_out_suggestion",
            index=8,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="list_select",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.list_select",
            index=9,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="carousel_select",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.carousel_select",
            index=10,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="telephony_play_audio",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.telephony_play_audio",
            index=11,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="telephony_synthesize_speech",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.telephony_synthesize_speech",
            index=12,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="telephony_transfer_call",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.telephony_transfer_call",
            index=13,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="rbm_text",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.rbm_text",
            index=14,
            number=18,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="rbm_standalone_rich_card",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.rbm_standalone_rich_card",
            index=15,
            number=19,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="rbm_carousel_rich_card",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.rbm_carousel_rich_card",
            index=16,
            number=20,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="browse_carousel_card",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.browse_carousel_card",
            index=17,
            number=22,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="table_card",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.table_card",
            index=18,
            number=23,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="media_content",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.media_content",
            index=19,
            number=24,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="platform",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.platform",
            index=20,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _INTENT_MESSAGE_TEXT,
        _INTENT_MESSAGE_IMAGE,
        _INTENT_MESSAGE_QUICKREPLIES,
        _INTENT_MESSAGE_CARD,
        _INTENT_MESSAGE_SIMPLERESPONSE,
        _INTENT_MESSAGE_SIMPLERESPONSES,
        _INTENT_MESSAGE_BASICCARD,
        _INTENT_MESSAGE_SUGGESTION,
        _INTENT_MESSAGE_SUGGESTIONS,
        _INTENT_MESSAGE_LINKOUTSUGGESTION,
        _INTENT_MESSAGE_LISTSELECT,
        _INTENT_MESSAGE_CAROUSELSELECT,
        _INTENT_MESSAGE_SELECTITEMINFO,
        _INTENT_MESSAGE_TELEPHONYPLAYAUDIO,
        _INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH,
        _INTENT_MESSAGE_TELEPHONYTRANSFERCALL,
        _INTENT_MESSAGE_RBMTEXT,
        _INTENT_MESSAGE_RBMCAROUSELCARD,
        _INTENT_MESSAGE_RBMSTANDALONECARD,
        _INTENT_MESSAGE_RBMCARDCONTENT,
        _INTENT_MESSAGE_RBMSUGGESTION,
        _INTENT_MESSAGE_RBMSUGGESTEDREPLY,
        _INTENT_MESSAGE_RBMSUGGESTEDACTION,
        _INTENT_MESSAGE_MEDIACONTENT,
        _INTENT_MESSAGE_BROWSECAROUSELCARD,
        _INTENT_MESSAGE_TABLECARD,
        _INTENT_MESSAGE_COLUMNPROPERTIES,
        _INTENT_MESSAGE_TABLECARDROW,
        _INTENT_MESSAGE_TABLECARDCELL,
    ],
    enum_types=[_INTENT_MESSAGE_PLATFORM],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="message",
            full_name="google.cloud.dialogflow.v2beta1.Intent.Message.message",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=1972,
    serialized_end=10230,
)

_INTENT_FOLLOWUPINTENTINFO = _descriptor.Descriptor(
    name="FollowupIntentInfo",
    full_name="google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="followup_intent_name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.followup_intent_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parent_followup_intent_name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.parent_followup_intent_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10232,
    serialized_end=10319,
)

_INTENT = _descriptor.Descriptor(
    name="Intent",
    full_name="google.cloud.dialogflow.v2beta1.Intent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="webhook_state",
            full_name="google.cloud.dialogflow.v2beta1.Intent.webhook_state",
            index=2,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="priority",
            full_name="google.cloud.dialogflow.v2beta1.Intent.priority",
            index=3,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="is_fallback",
            full_name="google.cloud.dialogflow.v2beta1.Intent.is_fallback",
            index=4,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ml_enabled",
            full_name="google.cloud.dialogflow.v2beta1.Intent.ml_enabled",
            index=5,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\030\001\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ml_disabled",
            full_name="google.cloud.dialogflow.v2beta1.Intent.ml_disabled",
            index=6,
            number=19,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_interaction",
            full_name="google.cloud.dialogflow.v2beta1.Intent.end_interaction",
            index=7,
            number=21,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="input_context_names",
            full_name="google.cloud.dialogflow.v2beta1.Intent.input_context_names",
            index=8,
            number=7,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="events",
            full_name="google.cloud.dialogflow.v2beta1.Intent.events",
            index=9,
            number=8,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="training_phrases",
            full_name="google.cloud.dialogflow.v2beta1.Intent.training_phrases",
            index=10,
            number=9,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="action",
            full_name="google.cloud.dialogflow.v2beta1.Intent.action",
            index=11,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="output_contexts",
            full_name="google.cloud.dialogflow.v2beta1.Intent.output_contexts",
            index=12,
            number=11,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reset_contexts",
            full_name="google.cloud.dialogflow.v2beta1.Intent.reset_contexts",
            index=13,
            number=12,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="google.cloud.dialogflow.v2beta1.Intent.parameters",
            index=14,
            number=13,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="messages",
            full_name="google.cloud.dialogflow.v2beta1.Intent.messages",
            index=15,
            number=14,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default_response_platforms",
            full_name="google.cloud.dialogflow.v2beta1.Intent.default_response_platforms",
            index=16,
            number=15,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="root_followup_intent_name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.root_followup_intent_name",
            index=17,
            number=16,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parent_followup_intent_name",
            full_name="google.cloud.dialogflow.v2beta1.Intent.parent_followup_intent_name",
            index=18,
            number=17,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="followup_intent_info",
            full_name="google.cloud.dialogflow.v2beta1.Intent.followup_intent_info",
            index=19,
            number=18,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _INTENT_TRAININGPHRASE,
        _INTENT_PARAMETER,
        _INTENT_MESSAGE,
        _INTENT_FOLLOWUPINTENTINFO,
    ],
    enum_types=[_INTENT_WEBHOOKSTATE],
    serialized_options=b"\352A\215\001\n dialogflow.googleapis.com/Intent\022)projects/{project}/agent/intents/{intent}\022>projects/{project}/locations/{location}/agent/intents/{intent}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=476,
    serialized_end=10585,
)


_LISTINTENTSREQUEST = _descriptor.Descriptor(
    name="ListIntentsRequest",
    full_name="google.cloud.dialogflow.v2beta1.ListIntentsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.ListIntentsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A"\022 dialogflow.googleapis.com/Intent',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.ListIntentsRequest.language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent_view",
            full_name="google.cloud.dialogflow.v2beta1.ListIntentsRequest.intent_view",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2beta1.ListIntentsRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListIntentsRequest.page_token",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10588,
    serialized_end=10799,
)


_LISTINTENTSRESPONSE = _descriptor.Descriptor(
    name="ListIntentsResponse",
    full_name="google.cloud.dialogflow.v2beta1.ListIntentsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="intents",
            full_name="google.cloud.dialogflow.v2beta1.ListIntentsResponse.intents",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListIntentsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10801,
    serialized_end=10905,
)


_GETINTENTREQUEST = _descriptor.Descriptor(
    name="GetIntentRequest",
    full_name="google.cloud.dialogflow.v2beta1.GetIntentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.GetIntentRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A"\n dialogflow.googleapis.com/Intent',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.GetIntentRequest.language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent_view",
            full_name="google.cloud.dialogflow.v2beta1.GetIntentRequest.intent_view",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=10908,
    serialized_end=11076,
)


_CREATEINTENTREQUEST = _descriptor.Descriptor(
    name="CreateIntentRequest",
    full_name="google.cloud.dialogflow.v2beta1.CreateIntentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.CreateIntentRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A"\022 dialogflow.googleapis.com/Intent',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent",
            full_name="google.cloud.dialogflow.v2beta1.CreateIntentRequest.intent",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.CreateIntentRequest.language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent_view",
            full_name="google.cloud.dialogflow.v2beta1.CreateIntentRequest.intent_view",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11079,
    serialized_end=11314,
)


_UPDATEINTENTREQUEST = _descriptor.Descriptor(
    name="UpdateIntentRequest",
    full_name="google.cloud.dialogflow.v2beta1.UpdateIntentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="intent",
            full_name="google.cloud.dialogflow.v2beta1.UpdateIntentRequest.intent",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.UpdateIntentRequest.language_code",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.UpdateIntentRequest.update_mask",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent_view",
            full_name="google.cloud.dialogflow.v2beta1.UpdateIntentRequest.intent_view",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11317,
    serialized_end=11543,
)


_DELETEINTENTREQUEST = _descriptor.Descriptor(
    name="DeleteIntentRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteIntentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.DeleteIntentRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A"\n dialogflow.googleapis.com/Intent',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11545,
    serialized_end=11622,
)


_BATCHUPDATEINTENTSREQUEST = _descriptor.Descriptor(
    name="BatchUpdateIntentsRequest",
    full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A"\022 dialogflow.googleapis.com/Intent',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent_batch_uri",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.intent_batch_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent_batch_inline",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.intent_batch_inline",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.language_code",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.update_mask",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intent_view",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.intent_view",
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="intent_batch",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.intent_batch",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=11625,
    serialized_end=11974,
)


_BATCHUPDATEINTENTSRESPONSE = _descriptor.Descriptor(
    name="BatchUpdateIntentsResponse",
    full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="intents",
            full_name="google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse.intents",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=11976,
    serialized_end=12062,
)


_BATCHDELETEINTENTSREQUEST = _descriptor.Descriptor(
    name="BatchDeleteIntentsRequest",
    full_name="google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A"\022 dialogflow.googleapis.com/Intent',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="intents",
            full_name="google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest.intents",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12065,
    serialized_end=12213,
)


_INTENTBATCH = _descriptor.Descriptor(
    name="IntentBatch",
    full_name="google.cloud.dialogflow.v2beta1.IntentBatch",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="intents",
            full_name="google.cloud.dialogflow.v2beta1.IntentBatch.intents",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=12215,
    serialized_end=12286,
)

_INTENT_TRAININGPHRASE_PART.containing_type = _INTENT_TRAININGPHRASE
_INTENT_TRAININGPHRASE.fields_by_name["type"].enum_type = _INTENT_TRAININGPHRASE_TYPE
_INTENT_TRAININGPHRASE.fields_by_name[
    "parts"
].message_type = _INTENT_TRAININGPHRASE_PART
_INTENT_TRAININGPHRASE.containing_type = _INTENT
_INTENT_TRAININGPHRASE_TYPE.containing_type = _INTENT_TRAININGPHRASE
_INTENT_PARAMETER.containing_type = _INTENT
_INTENT_MESSAGE_TEXT.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_IMAGE.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_QUICKREPLIES.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_CARD_BUTTON.containing_type = _INTENT_MESSAGE_CARD
_INTENT_MESSAGE_CARD.fields_by_name[
    "buttons"
].message_type = _INTENT_MESSAGE_CARD_BUTTON
_INTENT_MESSAGE_CARD.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_SIMPLERESPONSE.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_SIMPLERESPONSES.fields_by_name[
    "simple_responses"
].message_type = _INTENT_MESSAGE_SIMPLERESPONSE
_INTENT_MESSAGE_SIMPLERESPONSES.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_BASICCARD_BUTTON_OPENURIACTION.containing_type = (
    _INTENT_MESSAGE_BASICCARD_BUTTON
)
_INTENT_MESSAGE_BASICCARD_BUTTON.fields_by_name[
    "open_uri_action"
].message_type = _INTENT_MESSAGE_BASICCARD_BUTTON_OPENURIACTION
_INTENT_MESSAGE_BASICCARD_BUTTON.containing_type = _INTENT_MESSAGE_BASICCARD
_INTENT_MESSAGE_BASICCARD.fields_by_name["image"].message_type = _INTENT_MESSAGE_IMAGE
_INTENT_MESSAGE_BASICCARD.fields_by_name[
    "buttons"
].message_type = _INTENT_MESSAGE_BASICCARD_BUTTON
_INTENT_MESSAGE_BASICCARD.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_SUGGESTION.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_SUGGESTIONS.fields_by_name[
    "suggestions"
].message_type = _INTENT_MESSAGE_SUGGESTION
_INTENT_MESSAGE_SUGGESTIONS.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_LINKOUTSUGGESTION.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_LISTSELECT_ITEM.fields_by_name[
    "info"
].message_type = _INTENT_MESSAGE_SELECTITEMINFO
_INTENT_MESSAGE_LISTSELECT_ITEM.fields_by_name[
    "image"
].message_type = _INTENT_MESSAGE_IMAGE
_INTENT_MESSAGE_LISTSELECT_ITEM.containing_type = _INTENT_MESSAGE_LISTSELECT
_INTENT_MESSAGE_LISTSELECT.fields_by_name[
    "items"
].message_type = _INTENT_MESSAGE_LISTSELECT_ITEM
_INTENT_MESSAGE_LISTSELECT.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_CAROUSELSELECT_ITEM.fields_by_name[
    "info"
].message_type = _INTENT_MESSAGE_SELECTITEMINFO
_INTENT_MESSAGE_CAROUSELSELECT_ITEM.fields_by_name[
    "image"
].message_type = _INTENT_MESSAGE_IMAGE
_INTENT_MESSAGE_CAROUSELSELECT_ITEM.containing_type = _INTENT_MESSAGE_CAROUSELSELECT
_INTENT_MESSAGE_CAROUSELSELECT.fields_by_name[
    "items"
].message_type = _INTENT_MESSAGE_CAROUSELSELECT_ITEM
_INTENT_MESSAGE_CAROUSELSELECT.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_SELECTITEMINFO.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_TELEPHONYPLAYAUDIO.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.oneofs_by_name["source"].fields.append(
    _INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.fields_by_name["text"]
)
_INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.fields_by_name[
    "text"
].containing_oneof = _INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.oneofs_by_name["source"]
_INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.oneofs_by_name["source"].fields.append(
    _INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.fields_by_name["ssml"]
)
_INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.fields_by_name[
    "ssml"
].containing_oneof = _INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH.oneofs_by_name["source"]
_INTENT_MESSAGE_TELEPHONYTRANSFERCALL.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_RBMTEXT.fields_by_name[
    "rbm_suggestion"
].message_type = _INTENT_MESSAGE_RBMSUGGESTION
_INTENT_MESSAGE_RBMTEXT.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_RBMCAROUSELCARD.fields_by_name[
    "card_width"
].enum_type = _INTENT_MESSAGE_RBMCAROUSELCARD_CARDWIDTH
_INTENT_MESSAGE_RBMCAROUSELCARD.fields_by_name[
    "card_contents"
].message_type = _INTENT_MESSAGE_RBMCARDCONTENT
_INTENT_MESSAGE_RBMCAROUSELCARD.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_RBMCAROUSELCARD_CARDWIDTH.containing_type = (
    _INTENT_MESSAGE_RBMCAROUSELCARD
)
_INTENT_MESSAGE_RBMSTANDALONECARD.fields_by_name[
    "card_orientation"
].enum_type = _INTENT_MESSAGE_RBMSTANDALONECARD_CARDORIENTATION
_INTENT_MESSAGE_RBMSTANDALONECARD.fields_by_name[
    "thumbnail_image_alignment"
].enum_type = _INTENT_MESSAGE_RBMSTANDALONECARD_THUMBNAILIMAGEALIGNMENT
_INTENT_MESSAGE_RBMSTANDALONECARD.fields_by_name[
    "card_content"
].message_type = _INTENT_MESSAGE_RBMCARDCONTENT
_INTENT_MESSAGE_RBMSTANDALONECARD.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_RBMSTANDALONECARD_CARDORIENTATION.containing_type = (
    _INTENT_MESSAGE_RBMSTANDALONECARD
)
_INTENT_MESSAGE_RBMSTANDALONECARD_THUMBNAILIMAGEALIGNMENT.containing_type = (
    _INTENT_MESSAGE_RBMSTANDALONECARD
)
_INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA.fields_by_name[
    "height"
].enum_type = _INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA_HEIGHT
_INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA.containing_type = _INTENT_MESSAGE_RBMCARDCONTENT
_INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA_HEIGHT.containing_type = (
    _INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA
)
_INTENT_MESSAGE_RBMCARDCONTENT.fields_by_name[
    "media"
].message_type = _INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA
_INTENT_MESSAGE_RBMCARDCONTENT.fields_by_name[
    "suggestions"
].message_type = _INTENT_MESSAGE_RBMSUGGESTION
_INTENT_MESSAGE_RBMCARDCONTENT.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_RBMSUGGESTION.fields_by_name[
    "reply"
].message_type = _INTENT_MESSAGE_RBMSUGGESTEDREPLY
_INTENT_MESSAGE_RBMSUGGESTION.fields_by_name[
    "action"
].message_type = _INTENT_MESSAGE_RBMSUGGESTEDACTION
_INTENT_MESSAGE_RBMSUGGESTION.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_RBMSUGGESTION.oneofs_by_name["suggestion"].fields.append(
    _INTENT_MESSAGE_RBMSUGGESTION.fields_by_name["reply"]
)
_INTENT_MESSAGE_RBMSUGGESTION.fields_by_name[
    "reply"
].containing_oneof = _INTENT_MESSAGE_RBMSUGGESTION.oneofs_by_name["suggestion"]
_INTENT_MESSAGE_RBMSUGGESTION.oneofs_by_name["suggestion"].fields.append(
    _INTENT_MESSAGE_RBMSUGGESTION.fields_by_name["action"]
)
_INTENT_MESSAGE_RBMSUGGESTION.fields_by_name[
    "action"
].containing_oneof = _INTENT_MESSAGE_RBMSUGGESTION.oneofs_by_name["suggestion"]
_INTENT_MESSAGE_RBMSUGGESTEDREPLY.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONDIAL.containing_type = (
    _INTENT_MESSAGE_RBMSUGGESTEDACTION
)
_INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONOPENURI.containing_type = (
    _INTENT_MESSAGE_RBMSUGGESTEDACTION
)
_INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONSHARELOCATION.containing_type = (
    _INTENT_MESSAGE_RBMSUGGESTEDACTION
)
_INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name[
    "dial"
].message_type = _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONDIAL
_INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name[
    "open_url"
].message_type = _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONOPENURI
_INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name[
    "share_location"
].message_type = _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONSHARELOCATION
_INTENT_MESSAGE_RBMSUGGESTEDACTION.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_RBMSUGGESTEDACTION.oneofs_by_name["action"].fields.append(
    _INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name["dial"]
)
_INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name[
    "dial"
].containing_oneof = _INTENT_MESSAGE_RBMSUGGESTEDACTION.oneofs_by_name["action"]
_INTENT_MESSAGE_RBMSUGGESTEDACTION.oneofs_by_name["action"].fields.append(
    _INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name["open_url"]
)
_INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name[
    "open_url"
].containing_oneof = _INTENT_MESSAGE_RBMSUGGESTEDACTION.oneofs_by_name["action"]
_INTENT_MESSAGE_RBMSUGGESTEDACTION.oneofs_by_name["action"].fields.append(
    _INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name["share_location"]
)
_INTENT_MESSAGE_RBMSUGGESTEDACTION.fields_by_name[
    "share_location"
].containing_oneof = _INTENT_MESSAGE_RBMSUGGESTEDACTION.oneofs_by_name["action"]
_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.fields_by_name[
    "large_image"
].message_type = _INTENT_MESSAGE_IMAGE
_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.fields_by_name[
    "icon"
].message_type = _INTENT_MESSAGE_IMAGE
_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.containing_type = (
    _INTENT_MESSAGE_MEDIACONTENT
)
_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.oneofs_by_name["image"].fields.append(
    _INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.fields_by_name["large_image"]
)
_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.fields_by_name[
    "large_image"
].containing_oneof = _INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.oneofs_by_name[
    "image"
]
_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.oneofs_by_name["image"].fields.append(
    _INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.fields_by_name["icon"]
)
_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.fields_by_name[
    "icon"
].containing_oneof = _INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT.oneofs_by_name[
    "image"
]
_INTENT_MESSAGE_MEDIACONTENT.fields_by_name[
    "media_type"
].enum_type = _INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIATYPE
_INTENT_MESSAGE_MEDIACONTENT.fields_by_name[
    "media_objects"
].message_type = _INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT
_INTENT_MESSAGE_MEDIACONTENT.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIATYPE.containing_type = (
    _INTENT_MESSAGE_MEDIACONTENT
)
_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION.fields_by_name[
    "url_type_hint"
].enum_type = (
    _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION_URLTYPEHINT
)
_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION.containing_type = (
    _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM
)
_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION_URLTYPEHINT.containing_type = (
    _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION
)
_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM.fields_by_name[
    "open_uri_action"
].message_type = _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION
_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM.fields_by_name[
    "image"
].message_type = _INTENT_MESSAGE_IMAGE
_INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM.containing_type = (
    _INTENT_MESSAGE_BROWSECAROUSELCARD
)
_INTENT_MESSAGE_BROWSECAROUSELCARD.fields_by_name[
    "items"
].message_type = _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM
_INTENT_MESSAGE_BROWSECAROUSELCARD.fields_by_name[
    "image_display_options"
].enum_type = _INTENT_MESSAGE_BROWSECAROUSELCARD_IMAGEDISPLAYOPTIONS
_INTENT_MESSAGE_BROWSECAROUSELCARD.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_BROWSECAROUSELCARD_IMAGEDISPLAYOPTIONS.containing_type = (
    _INTENT_MESSAGE_BROWSECAROUSELCARD
)
_INTENT_MESSAGE_TABLECARD.fields_by_name["image"].message_type = _INTENT_MESSAGE_IMAGE
_INTENT_MESSAGE_TABLECARD.fields_by_name[
    "column_properties"
].message_type = _INTENT_MESSAGE_COLUMNPROPERTIES
_INTENT_MESSAGE_TABLECARD.fields_by_name[
    "rows"
].message_type = _INTENT_MESSAGE_TABLECARDROW
_INTENT_MESSAGE_TABLECARD.fields_by_name[
    "buttons"
].message_type = _INTENT_MESSAGE_BASICCARD_BUTTON
_INTENT_MESSAGE_TABLECARD.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_COLUMNPROPERTIES.fields_by_name[
    "horizontal_alignment"
].enum_type = _INTENT_MESSAGE_COLUMNPROPERTIES_HORIZONTALALIGNMENT
_INTENT_MESSAGE_COLUMNPROPERTIES.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_COLUMNPROPERTIES_HORIZONTALALIGNMENT.containing_type = (
    _INTENT_MESSAGE_COLUMNPROPERTIES
)
_INTENT_MESSAGE_TABLECARDROW.fields_by_name[
    "cells"
].message_type = _INTENT_MESSAGE_TABLECARDCELL
_INTENT_MESSAGE_TABLECARDROW.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE_TABLECARDCELL.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE.fields_by_name["text"].message_type = _INTENT_MESSAGE_TEXT
_INTENT_MESSAGE.fields_by_name["image"].message_type = _INTENT_MESSAGE_IMAGE
_INTENT_MESSAGE.fields_by_name[
    "quick_replies"
].message_type = _INTENT_MESSAGE_QUICKREPLIES
_INTENT_MESSAGE.fields_by_name["card"].message_type = _INTENT_MESSAGE_CARD
_INTENT_MESSAGE.fields_by_name[
    "payload"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_INTENT_MESSAGE.fields_by_name[
    "simple_responses"
].message_type = _INTENT_MESSAGE_SIMPLERESPONSES
_INTENT_MESSAGE.fields_by_name["basic_card"].message_type = _INTENT_MESSAGE_BASICCARD
_INTENT_MESSAGE.fields_by_name["suggestions"].message_type = _INTENT_MESSAGE_SUGGESTIONS
_INTENT_MESSAGE.fields_by_name[
    "link_out_suggestion"
].message_type = _INTENT_MESSAGE_LINKOUTSUGGESTION
_INTENT_MESSAGE.fields_by_name["list_select"].message_type = _INTENT_MESSAGE_LISTSELECT
_INTENT_MESSAGE.fields_by_name[
    "carousel_select"
].message_type = _INTENT_MESSAGE_CAROUSELSELECT
_INTENT_MESSAGE.fields_by_name[
    "telephony_play_audio"
].message_type = _INTENT_MESSAGE_TELEPHONYPLAYAUDIO
_INTENT_MESSAGE.fields_by_name[
    "telephony_synthesize_speech"
].message_type = _INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH
_INTENT_MESSAGE.fields_by_name[
    "telephony_transfer_call"
].message_type = _INTENT_MESSAGE_TELEPHONYTRANSFERCALL
_INTENT_MESSAGE.fields_by_name["rbm_text"].message_type = _INTENT_MESSAGE_RBMTEXT
_INTENT_MESSAGE.fields_by_name[
    "rbm_standalone_rich_card"
].message_type = _INTENT_MESSAGE_RBMSTANDALONECARD
_INTENT_MESSAGE.fields_by_name[
    "rbm_carousel_rich_card"
].message_type = _INTENT_MESSAGE_RBMCAROUSELCARD
_INTENT_MESSAGE.fields_by_name[
    "browse_carousel_card"
].message_type = _INTENT_MESSAGE_BROWSECAROUSELCARD
_INTENT_MESSAGE.fields_by_name["table_card"].message_type = _INTENT_MESSAGE_TABLECARD
_INTENT_MESSAGE.fields_by_name[
    "media_content"
].message_type = _INTENT_MESSAGE_MEDIACONTENT
_INTENT_MESSAGE.fields_by_name["platform"].enum_type = _INTENT_MESSAGE_PLATFORM
_INTENT_MESSAGE.containing_type = _INTENT
_INTENT_MESSAGE_PLATFORM.containing_type = _INTENT_MESSAGE
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["text"]
)
_INTENT_MESSAGE.fields_by_name[
    "text"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["image"]
)
_INTENT_MESSAGE.fields_by_name[
    "image"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["quick_replies"]
)
_INTENT_MESSAGE.fields_by_name[
    "quick_replies"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["card"]
)
_INTENT_MESSAGE.fields_by_name[
    "card"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["payload"]
)
_INTENT_MESSAGE.fields_by_name[
    "payload"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["simple_responses"]
)
_INTENT_MESSAGE.fields_by_name[
    "simple_responses"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["basic_card"]
)
_INTENT_MESSAGE.fields_by_name[
    "basic_card"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["suggestions"]
)
_INTENT_MESSAGE.fields_by_name[
    "suggestions"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["link_out_suggestion"]
)
_INTENT_MESSAGE.fields_by_name[
    "link_out_suggestion"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["list_select"]
)
_INTENT_MESSAGE.fields_by_name[
    "list_select"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["carousel_select"]
)
_INTENT_MESSAGE.fields_by_name[
    "carousel_select"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["telephony_play_audio"]
)
_INTENT_MESSAGE.fields_by_name[
    "telephony_play_audio"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["telephony_synthesize_speech"]
)
_INTENT_MESSAGE.fields_by_name[
    "telephony_synthesize_speech"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["telephony_transfer_call"]
)
_INTENT_MESSAGE.fields_by_name[
    "telephony_transfer_call"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["rbm_text"]
)
_INTENT_MESSAGE.fields_by_name[
    "rbm_text"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["rbm_standalone_rich_card"]
)
_INTENT_MESSAGE.fields_by_name[
    "rbm_standalone_rich_card"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["rbm_carousel_rich_card"]
)
_INTENT_MESSAGE.fields_by_name[
    "rbm_carousel_rich_card"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["browse_carousel_card"]
)
_INTENT_MESSAGE.fields_by_name[
    "browse_carousel_card"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["table_card"]
)
_INTENT_MESSAGE.fields_by_name[
    "table_card"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_MESSAGE.oneofs_by_name["message"].fields.append(
    _INTENT_MESSAGE.fields_by_name["media_content"]
)
_INTENT_MESSAGE.fields_by_name[
    "media_content"
].containing_oneof = _INTENT_MESSAGE.oneofs_by_name["message"]
_INTENT_FOLLOWUPINTENTINFO.containing_type = _INTENT
_INTENT.fields_by_name["webhook_state"].enum_type = _INTENT_WEBHOOKSTATE
_INTENT.fields_by_name["training_phrases"].message_type = _INTENT_TRAININGPHRASE
_INTENT.fields_by_name[
    "output_contexts"
].message_type = (
    google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_context__pb2._CONTEXT
)
_INTENT.fields_by_name["parameters"].message_type = _INTENT_PARAMETER
_INTENT.fields_by_name["messages"].message_type = _INTENT_MESSAGE
_INTENT.fields_by_name[
    "default_response_platforms"
].enum_type = _INTENT_MESSAGE_PLATFORM
_INTENT.fields_by_name["followup_intent_info"].message_type = _INTENT_FOLLOWUPINTENTINFO
_INTENT_WEBHOOKSTATE.containing_type = _INTENT
_LISTINTENTSREQUEST.fields_by_name["intent_view"].enum_type = _INTENTVIEW
_LISTINTENTSRESPONSE.fields_by_name["intents"].message_type = _INTENT
_GETINTENTREQUEST.fields_by_name["intent_view"].enum_type = _INTENTVIEW
_CREATEINTENTREQUEST.fields_by_name["intent"].message_type = _INTENT
_CREATEINTENTREQUEST.fields_by_name["intent_view"].enum_type = _INTENTVIEW
_UPDATEINTENTREQUEST.fields_by_name["intent"].message_type = _INTENT
_UPDATEINTENTREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEINTENTREQUEST.fields_by_name["intent_view"].enum_type = _INTENTVIEW
_BATCHUPDATEINTENTSREQUEST.fields_by_name[
    "intent_batch_inline"
].message_type = _INTENTBATCH
_BATCHUPDATEINTENTSREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_BATCHUPDATEINTENTSREQUEST.fields_by_name["intent_view"].enum_type = _INTENTVIEW
_BATCHUPDATEINTENTSREQUEST.oneofs_by_name["intent_batch"].fields.append(
    _BATCHUPDATEINTENTSREQUEST.fields_by_name["intent_batch_uri"]
)
_BATCHUPDATEINTENTSREQUEST.fields_by_name[
    "intent_batch_uri"
].containing_oneof = _BATCHUPDATEINTENTSREQUEST.oneofs_by_name["intent_batch"]
_BATCHUPDATEINTENTSREQUEST.oneofs_by_name["intent_batch"].fields.append(
    _BATCHUPDATEINTENTSREQUEST.fields_by_name["intent_batch_inline"]
)
_BATCHUPDATEINTENTSREQUEST.fields_by_name[
    "intent_batch_inline"
].containing_oneof = _BATCHUPDATEINTENTSREQUEST.oneofs_by_name["intent_batch"]
_BATCHUPDATEINTENTSRESPONSE.fields_by_name["intents"].message_type = _INTENT
_BATCHDELETEINTENTSREQUEST.fields_by_name["intents"].message_type = _INTENT
_INTENTBATCH.fields_by_name["intents"].message_type = _INTENT
DESCRIPTOR.message_types_by_name["Intent"] = _INTENT
DESCRIPTOR.message_types_by_name["ListIntentsRequest"] = _LISTINTENTSREQUEST
DESCRIPTOR.message_types_by_name["ListIntentsResponse"] = _LISTINTENTSRESPONSE
DESCRIPTOR.message_types_by_name["GetIntentRequest"] = _GETINTENTREQUEST
DESCRIPTOR.message_types_by_name["CreateIntentRequest"] = _CREATEINTENTREQUEST
DESCRIPTOR.message_types_by_name["UpdateIntentRequest"] = _UPDATEINTENTREQUEST
DESCRIPTOR.message_types_by_name["DeleteIntentRequest"] = _DELETEINTENTREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchUpdateIntentsRequest"
] = _BATCHUPDATEINTENTSREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchUpdateIntentsResponse"
] = _BATCHUPDATEINTENTSRESPONSE
DESCRIPTOR.message_types_by_name[
    "BatchDeleteIntentsRequest"
] = _BATCHDELETEINTENTSREQUEST
DESCRIPTOR.message_types_by_name["IntentBatch"] = _INTENTBATCH
DESCRIPTOR.enum_types_by_name["IntentView"] = _INTENTVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Intent = _reflection.GeneratedProtocolMessageType(
    "Intent",
    (_message.Message,),
    {
        "TrainingPhrase": _reflection.GeneratedProtocolMessageType(
            "TrainingPhrase",
            (_message.Message,),
            {
                "Part": _reflection.GeneratedProtocolMessageType(
                    "Part",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_TRAININGPHRASE_PART,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Represents a part of a training phrase.
      
      Attributes:
          text:
              Required. The text for this part.
          entity_type:
              Optional. The entity type name prefixed with ``@``. This field
              is required for annotated parts of the training phrase.
          alias:
              Optional. The parameter name for the value extracted from the
              annotated part of the example. This field is required for
              annotated parts of the training phrase.
          user_defined:
              Optional. Indicates whether the text was manually annotated.
              This field is set to true when the Dialogflow Console is used
              to manually annotate the part. When creating an annotated part
              with the API, you must set this to true.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part)
                    },
                ),
                "DESCRIPTOR": _INTENT_TRAININGPHRASE,
                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                "__doc__": """Represents an example that the agent is trained on.
    
    Attributes:
        name:
            Output only. The unique identifier of this training phrase.
        type:
            Required. The type of the training phrase.
        parts:
            Required. The ordered list of training phrase parts. The parts
            are concatenated in order to form the training phrase.  Note:
            The API does not automatically annotate training phrases like
            the Dialogflow Console does.  Note: Do not forget to include
            whitespace at part boundaries, so the training phrase is well
            formatted when the parts are concatenated.  If the training
            phrase does not need to be annotated with parameters, you just
            need a single part with only the [Part.text][google.cloud.dial
            ogflow.v2beta1.Intent.TrainingPhrase.Part.text] field set.  If
            you want to annotate the training phrase, you must create
            multiple parts, where the fields of each part are populated in
            one of two ways:  -  ``Part.text`` is set to a part of the
            phrase that has no parameters. -  ``Part.text`` is set to a
            part of the phrase that you want to    annotate, and the
            ``entity_type``, ``alias``, and ``user_defined``    fields are
            all set.
        times_added_count:
            Optional. Indicates how many times this example was added to
            the intent. Each time a developer adds an existing sample by
            editing an intent or training, this counter is increased.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase)
            },
        ),
        "Parameter": _reflection.GeneratedProtocolMessageType(
            "Parameter",
            (_message.Message,),
            {
                "DESCRIPTOR": _INTENT_PARAMETER,
                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                "__doc__": """Represents intent parameters.
    
    Attributes:
        name:
            The unique identifier of this parameter.
        display_name:
            Required. The name of the parameter.
        value:
            Optional. The definition of the parameter value. It can be:  -
            a constant string, -  a parameter value defined as
            ``$parameter_name``, -  an original parameter value defined as
            ``$parameter_name.original``, -  a parameter value from some
            context defined as    ``#context_name.parameter_name``.
        default_value:
            Optional. The default value to use when the ``value`` yields
            an empty result. Default values can be extracted from contexts
            by using the following syntax:
            ``#context_name.parameter_name``.
        entity_type_display_name:
            Optional. The name of the entity type, prefixed with ``@``,
            that describes values of the parameter. If the parameter is
            required, this must be provided.
        mandatory:
            Optional. Indicates whether the parameter is required. That
            is, whether the intent cannot be completed without collecting
            the parameter value.
        prompts:
            Optional. The collection of prompts that the agent can present
            to the user in order to collect a value for the parameter.
        is_list:
            Optional. Indicates whether the parameter represents a list of
            values.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Parameter)
            },
        ),
        "Message": _reflection.GeneratedProtocolMessageType(
            "Message",
            (_message.Message,),
            {
                "Text": _reflection.GeneratedProtocolMessageType(
                    "Text",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_TEXT,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The text response message.
      
      Attributes:
          text:
              Optional. The collection of the agent’s responses.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.Text)
                    },
                ),
                "Image": _reflection.GeneratedProtocolMessageType(
                    "Image",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_IMAGE,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The image response message.
      
      Attributes:
          image_uri:
              Optional. The public URI to an image file.
          accessibility_text:
              A text description of the image to be used for accessibility,
              e.g., screen readers. Required if image_uri is set for
              CarouselSelect.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.Image)
                    },
                ),
                "QuickReplies": _reflection.GeneratedProtocolMessageType(
                    "QuickReplies",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_QUICKREPLIES,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The quick replies response message.
      
      Attributes:
          title:
              Optional. The title of the collection of quick replies.
          quick_replies:
              Optional. The collection of quick replies.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies)
                    },
                ),
                "Card": _reflection.GeneratedProtocolMessageType(
                    "Card",
                    (_message.Message,),
                    {
                        "Button": _reflection.GeneratedProtocolMessageType(
                            "Button",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _INTENT_MESSAGE_CARD_BUTTON,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """Optional. Contains information about a button.
        
        Attributes:
            text:
                Optional. The text to show on the button.
            postback:
                Optional. The text to send back to the Dialogflow API or a URI
                to open.
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button)
                            },
                        ),
                        "DESCRIPTOR": _INTENT_MESSAGE_CARD,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The card response message.
      
      Attributes:
          title:
              Optional. The title of the card.
          subtitle:
              Optional. The subtitle of the card.
          image_uri:
              Optional. The public URI to an image file for the card.
          buttons:
              Optional. The collection of card buttons.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.Card)
                    },
                ),
                "SimpleResponse": _reflection.GeneratedProtocolMessageType(
                    "SimpleResponse",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_SIMPLERESPONSE,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The simple response message containing speech or text.
      
      Attributes:
          text_to_speech:
              One of text_to_speech or ssml must be provided. The plain text
              of the speech output. Mutually exclusive with ssml.
          ssml:
              One of text_to_speech or ssml must be provided. Structured
              spoken response to the user in the SSML format. Mutually
              exclusive with text_to_speech.
          display_text:
              Optional. The text to display.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse)
                    },
                ),
                "SimpleResponses": _reflection.GeneratedProtocolMessageType(
                    "SimpleResponses",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_SIMPLERESPONSES,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The collection of simple response candidates. This message in
      ``QueryResult.fulfillment_messages`` and
      ``WebhookResponse.fulfillment_messages`` should contain only one
      ``SimpleResponse``.
      
      Attributes:
          simple_responses:
              Required. The list of simple responses.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses)
                    },
                ),
                "BasicCard": _reflection.GeneratedProtocolMessageType(
                    "BasicCard",
                    (_message.Message,),
                    {
                        "Button": _reflection.GeneratedProtocolMessageType(
                            "Button",
                            (_message.Message,),
                            {
                                "OpenUriAction": _reflection.GeneratedProtocolMessageType(
                                    "OpenUriAction",
                                    (_message.Message,),
                                    {
                                        "DESCRIPTOR": _INTENT_MESSAGE_BASICCARD_BUTTON_OPENURIACTION,
                                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                        "__doc__": """Opens the given URI.
          
          Attributes:
              uri:
                  Required. The HTTP or HTTPS scheme URI.
          """,
                                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction)
                                    },
                                ),
                                "DESCRIPTOR": _INTENT_MESSAGE_BASICCARD_BUTTON,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """The button object that appears at the bottom of a card.
        
        Attributes:
            title:
                Required. The title of the button.
            open_uri_action:
                Required. Action to take when a user taps on the button.
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button)
                            },
                        ),
                        "DESCRIPTOR": _INTENT_MESSAGE_BASICCARD,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The basic card message. Useful for displaying information.
      
      Attributes:
          title:
              Optional. The title of the card.
          subtitle:
              Optional. The subtitle of the card.
          formatted_text:
              Required, unless image is present. The body text of the card.
          image:
              Optional. The image for the card.
          buttons:
              Optional. The collection of card buttons.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard)
                    },
                ),
                "Suggestion": _reflection.GeneratedProtocolMessageType(
                    "Suggestion",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_SUGGESTION,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The suggestion chip message that the user can tap to quickly post a
      reply to the conversation.
      
      Attributes:
          title:
              Required. The text shown the in the suggestion chip.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion)
                    },
                ),
                "Suggestions": _reflection.GeneratedProtocolMessageType(
                    "Suggestions",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_SUGGESTIONS,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The collection of suggestions.
      
      Attributes:
          suggestions:
              Required. The list of suggested replies.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions)
                    },
                ),
                "LinkOutSuggestion": _reflection.GeneratedProtocolMessageType(
                    "LinkOutSuggestion",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_LINKOUTSUGGESTION,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The suggestion chip message that allows the user to jump out to the
      app or website associated with this agent.
      
      Attributes:
          destination_name:
              Required. The name of the app or site this chip is linking to.
          uri:
              Required. The URI of the app or site to open when the user
              taps the suggestion chip.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion)
                    },
                ),
                "ListSelect": _reflection.GeneratedProtocolMessageType(
                    "ListSelect",
                    (_message.Message,),
                    {
                        "Item": _reflection.GeneratedProtocolMessageType(
                            "Item",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _INTENT_MESSAGE_LISTSELECT_ITEM,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """An item in the list.
        
        Attributes:
            info:
                Required. Additional information about this option.
            title:
                Required. The title of the list item.
            description:
                Optional. The main text describing the item.
            image:
                Optional. The image to display.
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item)
                            },
                        ),
                        "DESCRIPTOR": _INTENT_MESSAGE_LISTSELECT,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The card for presenting a list of options to select from.
      
      Attributes:
          title:
              Optional. The overall title of the list.
          items:
              Required. List items.
          subtitle:
              Optional. Subtitle of the list.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect)
                    },
                ),
                "CarouselSelect": _reflection.GeneratedProtocolMessageType(
                    "CarouselSelect",
                    (_message.Message,),
                    {
                        "Item": _reflection.GeneratedProtocolMessageType(
                            "Item",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _INTENT_MESSAGE_CAROUSELSELECT_ITEM,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """An item in the carousel.
        
        Attributes:
            info:
                Required. Additional info about the option item.
            title:
                Required. Title of the carousel item.
            description:
                Optional. The body text of the card.
            image:
                Optional. The image to display.
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item)
                            },
                        ),
                        "DESCRIPTOR": _INTENT_MESSAGE_CAROUSELSELECT,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The card for presenting a carousel of options to select from.
      
      Attributes:
          items:
              Required. Carousel items.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect)
                    },
                ),
                "SelectItemInfo": _reflection.GeneratedProtocolMessageType(
                    "SelectItemInfo",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_SELECTITEMINFO,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Additional info about the select item for when it is triggered in a
      dialog.
      
      Attributes:
          key:
              Required. A unique key that will be sent back to the agent if
              this response is given.
          synonyms:
              Optional. A list of synonyms that can also be used to trigger
              this item in dialog.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo)
                    },
                ),
                "TelephonyPlayAudio": _reflection.GeneratedProtocolMessageType(
                    "TelephonyPlayAudio",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_TELEPHONYPLAYAUDIO,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Plays audio from a file in Telephony Gateway.
      
      Attributes:
          audio_uri:
              Required. URI to a Google Cloud Storage object containing the
              audio to play, e.g., “gs://bucket/object”. The object must
              contain a single channel (mono) of linear PCM audio (2 bytes /
              sample) at 8kHz.  This object must be readable by the
              ``service-<Project Number>@gcp-sa-
              dialogflow.iam.gserviceaccount.com`` service account where is
              the number of the Telephony Gateway project (usually the same
              as the Dialogflow agent project). If the Google Cloud Storage
              bucket is in the Telephony Gateway project, this permission is
              added by default when enabling the Dialogflow V2 API.  For
              audio from other sources, consider using the
              ``TelephonySynthesizeSpeech`` message with SSML.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio)
                    },
                ),
                "TelephonySynthesizeSpeech": _reflection.GeneratedProtocolMessageType(
                    "TelephonySynthesizeSpeech",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_TELEPHONYSYNTHESIZESPEECH,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Synthesizes speech and plays back the synthesized audio to the caller
      in Telephony Gateway.  Telephony Gateway takes the synthesizer
      settings from ``DetectIntentResponse.output_audio_config`` which can
      either be set at request-level or can come from the agent-level
      synthesizer config.
      
      Attributes:
          source:
              Required. The source to be synthesized.
          text:
              The raw text to be synthesized.
          ssml:
              The SSML to be synthesized. For more information, see `SSML
              <https://developers.google.com/actions/reference/ssml>`__.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech)
                    },
                ),
                "TelephonyTransferCall": _reflection.GeneratedProtocolMessageType(
                    "TelephonyTransferCall",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_TELEPHONYTRANSFERCALL,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Transfers the call in Telephony Gateway.
      
      Attributes:
          phone_number:
              Required. The phone number to transfer the call to in `E.164
              format <https://en.wikipedia.org/wiki/E.164>`__.  We currently
              only allow transferring to US numbers (+1xxxyyyzzzz).
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall)
                    },
                ),
                "RbmText": _reflection.GeneratedProtocolMessageType(
                    "RbmText",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_RBMTEXT,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Rich Business Messaging (RBM) text response with suggestions.
      
      Attributes:
          text:
              Required. Text sent and displayed to the user.
          rbm_suggestion:
              Optional. One or more suggestions to show to the user.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmText)
                    },
                ),
                "RbmCarouselCard": _reflection.GeneratedProtocolMessageType(
                    "RbmCarouselCard",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_RBMCAROUSELCARD,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Carousel Rich Business Messaging (RBM) rich card.  Rich cards allow
      you to respond to users with more vivid content, e.g. with media and
      suggestions.  If you want to show a single card with more control over
      the layout, please use [RbmStandaloneCard][google.cloud.dialogflow.v2b
      eta1.Intent.Message.RbmStandaloneCard] instead.
      
      Attributes:
          card_width:
              Required. The width of the cards in the carousel.
          card_contents:
              Required. The cards in the carousel. A carousel must have at
              least 2 cards and at most 10.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard)
                    },
                ),
                "RbmStandaloneCard": _reflection.GeneratedProtocolMessageType(
                    "RbmStandaloneCard",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_RBMSTANDALONECARD,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Standalone Rich Business Messaging (RBM) rich card.  Rich cards allow
      you to respond to users with more vivid content, e.g. with media and
      suggestions.  You can group multiple rich cards into one using [RbmCar
      ouselCard][google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselC
      ard] but carousel cards will give you less control over the card
      layout.
      
      Attributes:
          card_orientation:
              Required. Orientation of the card.
          thumbnail_image_alignment:
              Required if orientation is horizontal. Image preview alignment
              for standalone cards with horizontal layout.
          card_content:
              Required. Card content.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard)
                    },
                ),
                "RbmCardContent": _reflection.GeneratedProtocolMessageType(
                    "RbmCardContent",
                    (_message.Message,),
                    {
                        "RbmMedia": _reflection.GeneratedProtocolMessageType(
                            "RbmMedia",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _INTENT_MESSAGE_RBMCARDCONTENT_RBMMEDIA,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """Rich Business Messaging (RBM) Media displayed in Cards The following
        media-types are currently supported:  Image Types  -  image/jpeg -
        image/jpg’ -  image/gif -  image/png  Video Types  -  video/h263 -
        video/m4v -  video/mp4 -  video/mpeg -  video/mpeg4 -  video/webm
        
        Attributes:
            file_uri:
                Required. Publicly reachable URI of the file. The RBM platform
                determines the MIME type of the file from the content-type
                field in the HTTP headers when the platform fetches the file.
                The content-type field must be present and accurate in the
                HTTP response from the URL.
            thumbnail_uri:
                Optional. Publicly reachable URI of the thumbnail.If you don’t
                provide a thumbnail URI, the RBM platform displays a blank
                placeholder thumbnail until the user’s device downloads the
                file. Depending on the user’s setting, the file may not
                download automatically and may require the user to tap a
                download button.
            height:
                Required for cards with vertical orientation. The height of
                the media within a rich card with a vertical layout. For a
                standalone card with horizontal layout, height is not
                customizable, and this field is ignored.
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia)
                            },
                        ),
                        "DESCRIPTOR": _INTENT_MESSAGE_RBMCARDCONTENT,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Rich Business Messaging (RBM) Card content
      
      Attributes:
          title:
              Optional. Title of the card (at most 200 bytes).  At least one
              of the title, description or media must be set.
          description:
              Optional. Description of the card (at most 2000 bytes).  At
              least one of the title, description or media must be set.
          media:
              Optional. However at least one of the title, description or
              media must be set. Media (image, GIF or a video) to include in
              the card.
          suggestions:
              Optional. List of suggestions to include in the card.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent)
                    },
                ),
                "RbmSuggestion": _reflection.GeneratedProtocolMessageType(
                    "RbmSuggestion",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_RBMSUGGESTION,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Rich Business Messaging (RBM) suggestion. Suggestions allow user to
      easily select/click a predefined response or perform an action (like
      opening a web uri).
      
      Attributes:
          suggestion:
              Predefined suggested response or action for user to choose
          reply:
              Predefined replies for user to select instead of typing
          action:
              Predefined client side actions that user can choose
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion)
                    },
                ),
                "RbmSuggestedReply": _reflection.GeneratedProtocolMessageType(
                    "RbmSuggestedReply",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_RBMSUGGESTEDREPLY,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Rich Business Messaging (RBM) suggested reply that the user can click
      instead of typing in their own response.
      
      Attributes:
          text:
              Suggested reply text.
          postback_data:
              Opaque payload that the Dialogflow receives in a user event
              when the user taps the suggested reply. This data will be also
              forwarded to webhook to allow performing custom business
              logic.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply)
                    },
                ),
                "RbmSuggestedAction": _reflection.GeneratedProtocolMessageType(
                    "RbmSuggestedAction",
                    (_message.Message,),
                    {
                        "RbmSuggestedActionDial": _reflection.GeneratedProtocolMessageType(
                            "RbmSuggestedActionDial",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONDIAL,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """Opens the user’s default dialer app with the specified phone number
        but does not dial automatically.
        
        Attributes:
            phone_number:
                Required. The phone number to fill in the default dialer app.
                This field should be in `E.164
                <https://en.wikipedia.org/wiki/E.164>`__ format. An example of
                a correctly formatted phone number: +15556767888.
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial)
                            },
                        ),
                        "RbmSuggestedActionOpenUri": _reflection.GeneratedProtocolMessageType(
                            "RbmSuggestedActionOpenUri",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONOPENURI,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """Opens the user’s default web browser app to the specified uri If the
        user has an app installed that is registered as the default handler
        for the URL, then this app will be opened instead, and its icon will
        be used in the suggested action UI.
        
        Attributes:
            uri:
                Required. The uri to open on the user device
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri)
                            },
                        ),
                        "RbmSuggestedActionShareLocation": _reflection.GeneratedProtocolMessageType(
                            "RbmSuggestedActionShareLocation",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _INTENT_MESSAGE_RBMSUGGESTEDACTION_RBMSUGGESTEDACTIONSHARELOCATION,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """Opens the device’s location chooser so the user can pick a location to
        send back to the agent.""",
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation)
                            },
                        ),
                        "DESCRIPTOR": _INTENT_MESSAGE_RBMSUGGESTEDACTION,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Rich Business Messaging (RBM) suggested client-side action that the
      user can choose from the card.
      
      Attributes:
          text:
              Text to display alongside the action.
          postback_data:
              Opaque payload that the Dialogflow receives in a user event
              when the user taps the suggested action. This data will be
              also forwarded to webhook to allow performing custom business
              logic.
          action:
              Action that needs to be triggered.
          dial:
              Suggested client side action: Dial a phone number
          open_url:
              Suggested client side action: Open a URI on device
          share_location:
              Suggested client side action: Share user location
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction)
                    },
                ),
                "MediaContent": _reflection.GeneratedProtocolMessageType(
                    "MediaContent",
                    (_message.Message,),
                    {
                        "ResponseMediaObject": _reflection.GeneratedProtocolMessageType(
                            "ResponseMediaObject",
                            (_message.Message,),
                            {
                                "DESCRIPTOR": _INTENT_MESSAGE_MEDIACONTENT_RESPONSEMEDIAOBJECT,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """Response media object for media content card.
        
        Attributes:
            name:
                Required. Name of media card.
            description:
                Optional. Description of media card.
            image:
                Image to show with the media card.
            large_image:
                Optional. Image to display above media content.
            icon:
                Optional. Icon to display above media content.
            content_url:
                Required. Url where the media is stored.
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject)
                            },
                        ),
                        "DESCRIPTOR": _INTENT_MESSAGE_MEDIACONTENT,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """The media content card for Actions on Google.
      
      Attributes:
          media_type:
              Optional. What type of media is the content (ie “audio”).
          media_objects:
              Required. List of media objects.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent)
                    },
                ),
                "BrowseCarouselCard": _reflection.GeneratedProtocolMessageType(
                    "BrowseCarouselCard",
                    (_message.Message,),
                    {
                        "BrowseCarouselCardItem": _reflection.GeneratedProtocolMessageType(
                            "BrowseCarouselCardItem",
                            (_message.Message,),
                            {
                                "OpenUrlAction": _reflection.GeneratedProtocolMessageType(
                                    "OpenUrlAction",
                                    (_message.Message,),
                                    {
                                        "DESCRIPTOR": _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM_OPENURLACTION,
                                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                        "__doc__": """Actions on Google action to open a given url.
          
          Attributes:
              url:
                  Required. URL
              url_type_hint:
                  Optional. Specifies the type of viewer that is used when
                  opening the URL. Defaults to opening via web browser.
          """,
                                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction)
                                    },
                                ),
                                "DESCRIPTOR": _INTENT_MESSAGE_BROWSECAROUSELCARD_BROWSECAROUSELCARDITEM,
                                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                                "__doc__": """Browsing carousel tile
        
        Attributes:
            open_uri_action:
                Required. Action to present to the user.
            title:
                Required. Title of the carousel item. Maximum of two lines of
                text.
            description:
                Optional. Description of the carousel item. Maximum of four
                lines of text.
            image:
                Optional. Hero image for the carousel item.
            footer:
                Optional. Text that appears at the bottom of the Browse
                Carousel Card. Maximum of one line of text.
        """,
                                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem)
                            },
                        ),
                        "DESCRIPTOR": _INTENT_MESSAGE_BROWSECAROUSELCARD,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Browse Carousel Card for Actions on Google. https://developers.google.
      com/actions/assistant/responses#browsing_carousel
      
      Attributes:
          items:
              Required. List of items in the Browse Carousel Card. Minimum
              of two items, maximum of ten.
          image_display_options:
              Optional. Settings for displaying the image. Applies to every
              image in [items][google.cloud.dialogflow.v2beta1.Intent.Messag
              e.BrowseCarouselCard.items].
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard)
                    },
                ),
                "TableCard": _reflection.GeneratedProtocolMessageType(
                    "TableCard",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_TABLECARD,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Table card for Actions on Google.
      
      Attributes:
          title:
              Required. Title of the card.
          subtitle:
              Optional. Subtitle to the title.
          image:
              Optional. Image which should be displayed on the card.
          column_properties:
              Optional. Display properties for the columns in this table.
          rows:
              Optional. Rows in this table of data.
          buttons:
              Optional. List of buttons for the card.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.TableCard)
                    },
                ),
                "ColumnProperties": _reflection.GeneratedProtocolMessageType(
                    "ColumnProperties",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_COLUMNPROPERTIES,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Column properties for
      [TableCard][google.cloud.dialogflow.v2beta1.Intent.Message.TableCard].
      
      Attributes:
          header:
              Required. Column heading.
          horizontal_alignment:
              Optional. Defines text alignment for all cells in this column.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties)
                    },
                ),
                "TableCardRow": _reflection.GeneratedProtocolMessageType(
                    "TableCardRow",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_TABLECARDROW,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Row of
      [TableCard][google.cloud.dialogflow.v2beta1.Intent.Message.TableCard].
      
      Attributes:
          cells:
              Optional. List of cells that make up this row.
          divider_after:
              Optional. Whether to add a visual divider after this row.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow)
                    },
                ),
                "TableCardCell": _reflection.GeneratedProtocolMessageType(
                    "TableCardCell",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _INTENT_MESSAGE_TABLECARDCELL,
                        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                        "__doc__": """Cell of [TableCardRow][google.cloud.dialogflow.v2beta1.Intent.Message.
      TableCardRow].
      
      Attributes:
          text:
              Required. Text in this cell.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell)
                    },
                ),
                "DESCRIPTOR": _INTENT_MESSAGE,
                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                "__doc__": """Corresponds to the ``Response`` field in the Dialogflow console.
    
    Attributes:
        message:
            Required. The rich response message.
        text:
            Returns a text response.
        image:
            Displays an image.
        quick_replies:
            Displays quick replies.
        card:
            Displays a card.
        payload:
            A custom platform-specific response.
        simple_responses:
            Returns a voice or text-only response for Actions on Google.
        basic_card:
            Displays a basic card for Actions on Google.
        suggestions:
            Displays suggestion chips for Actions on Google.
        link_out_suggestion:
            Displays a link out suggestion chip for Actions on Google.
        list_select:
            Displays a list card for Actions on Google.
        carousel_select:
            Displays a carousel card for Actions on Google.
        telephony_play_audio:
            Plays audio from a file in Telephony Gateway.
        telephony_synthesize_speech:
            Synthesizes speech in Telephony Gateway.
        telephony_transfer_call:
            Transfers the call in Telephony Gateway.
        rbm_text:
            Rich Business Messaging (RBM) text response.  RBM allows
            businesses to send enriched and branded versions of SMS. See
            https://jibe.google.com/business-messaging.
        rbm_standalone_rich_card:
            Standalone Rich Business Messaging (RBM) rich card response.
        rbm_carousel_rich_card:
            Rich Business Messaging (RBM) carousel rich card response.
        browse_carousel_card:
            Browse carousel card for Actions on Google.
        table_card:
            Table card for Actions on Google.
        media_content:
            The media content card for Actions on Google.
        platform:
            Optional. The platform that this message is intended for.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.Message)
            },
        ),
        "FollowupIntentInfo": _reflection.GeneratedProtocolMessageType(
            "FollowupIntentInfo",
            (_message.Message,),
            {
                "DESCRIPTOR": _INTENT_FOLLOWUPINTENTINFO,
                "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
                "__doc__": """Represents a single followup intent in the chain.
    
    Attributes:
        followup_intent_name:
            The unique identifier of the followup intent. Format:
            ``projects/<Project ID>/agent/intents/<Intent ID>``.
        parent_followup_intent_name:
            The unique identifier of the followup intent’s parent. Format:
            ``projects/<Project ID>/agent/intents/<Intent ID>``.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo)
            },
        ),
        "DESCRIPTOR": _INTENT,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """An intent categorizes an end-user’s intention for one conversation
  turn. For each agent, you define many intents, where your combined
  intents can handle a complete conversation. When an end-user writes or
  says something, referred to as an end-user expression or end-user
  input, Dialogflow matches the end-user input to the best intent in
  your agent. Matching an intent is also known as intent classification.
  For more information, see the `intent guide
  <https://cloud.google.com/dialogflow/docs/intents-overview>`__.
  
  Attributes:
      name:
          Optional. The unique identifier of this intent. Required for [
          Intents.UpdateIntent][google.cloud.dialogflow.v2beta1.Intents.
          UpdateIntent] and [Intents.BatchUpdateIntents][google.cloud.di
          alogflow.v2beta1.Intents.BatchUpdateIntents] methods. Format:
          ``projects/<Project ID>/agent/intents/<Intent ID>``.
      display_name:
          Required. The name of this intent.
      webhook_state:
          Optional. Indicates whether webhooks are enabled for the
          intent.
      priority:
          Optional. The priority of this intent. Higher numbers
          represent higher priorities.  -  If the supplied value is
          unspecified or 0, the service translates the    value to
          500,000, which corresponds to the ``Normal`` priority in the
          console. -  If the supplied value is negative, the intent is
          ignored in runtime    detect intent requests.
      is_fallback:
          Optional. Indicates whether this is a fallback intent.
      ml_enabled:
          Optional. Indicates whether Machine Learning is enabled for
          the intent. Note: If ``ml_enabled`` setting is set to false,
          then this intent is not taken into account during inference in
          ``ML ONLY`` match mode. Also, auto-markup in the UI is turned
          off. DEPRECATED! Please use ``ml_disabled`` field instead.
          NOTE: If both ``ml_enabled`` and ``ml_disabled`` are either
          not set or false, then the default value is determined as
          follows: - Before April 15th, 2018 the default is: ml_enabled
          = false / ml_disabled = true. - After April 15th, 2018 the
          default is: ml_enabled = true / ml_disabled = false.
      ml_disabled:
          Optional. Indicates whether Machine Learning is disabled for
          the intent. Note: If ``ml_disabled`` setting is set to true,
          then this intent is not taken into account during inference in
          ``ML ONLY`` match mode. Also, auto-markup in the UI is turned
          off.
      end_interaction:
          Optional. Indicates that this intent ends an interaction. Some
          integrations (e.g., Actions on Google or Dialogflow phone
          gateway) use this information to close interaction with an end
          user. Default is false.
      input_context_names:
          Optional. The list of context names required for this intent
          to be triggered. Format: ``projects/<Project
          ID>/agent/sessions/-/contexts/<Context ID>``.
      events:
          Optional. The collection of event names that trigger the
          intent. If the collection of input contexts is not empty, all
          of the contexts must be present in the active user session for
          an event to trigger this intent. Event names are limited to
          150 characters.
      training_phrases:
          Optional. The collection of examples that the agent is trained
          on.
      action:
          Optional. The name of the action associated with the intent.
          Note: The action name must not contain whitespaces.
      output_contexts:
          Optional. The collection of contexts that are activated when
          the intent is matched. Context messages in this collection
          should not set the parameters field. Setting the
          ``lifespan_count`` to 0 will reset the context when the intent
          is matched. Format: ``projects/<Project
          ID>/agent/sessions/-/contexts/<Context ID>``.
      reset_contexts:
          Optional. Indicates whether to delete all contexts in the
          current session when this intent is matched.
      parameters:
          Optional. The collection of parameters associated with the
          intent.
      messages:
          Optional. The collection of rich messages corresponding to the
          ``Response`` field in the Dialogflow console.
      default_response_platforms:
          Optional. The list of platforms for which the first responses
          will be copied from the messages in PLATFORM_UNSPECIFIED
          (i.e. default platform).
      root_followup_intent_name:
          Output only. The unique identifier of the root intent in the
          chain of followup intents. It identifies the correct followup
          intents chain for this intent.  Format: ``projects/<Project
          ID>/agent/intents/<Intent ID>``.
      parent_followup_intent_name:
          Optional. The unique identifier of the parent intent in the
          chain of followup intents. You can set this field when
          creating an intent, for example with [CreateIntent][google.clo
          ud.dialogflow.v2beta1.Intents.CreateIntent] or [BatchUpdateInt
          ents][google.cloud.dialogflow.v2beta1.Intents.BatchUpdateInten
          ts], in order to make this intent a followup intent.  It
          identifies the parent followup intent. Format:
          ``projects/<Project ID>/agent/intents/<Intent ID>``.
      followup_intent_info:
          Output only. Information about all followup intents that have
          this intent as a direct or indirect parent. We populate this
          field only in the output.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Intent)
    },
)
_sym_db.RegisterMessage(Intent)
_sym_db.RegisterMessage(Intent.TrainingPhrase)
_sym_db.RegisterMessage(Intent.TrainingPhrase.Part)
_sym_db.RegisterMessage(Intent.Parameter)
_sym_db.RegisterMessage(Intent.Message)
_sym_db.RegisterMessage(Intent.Message.Text)
_sym_db.RegisterMessage(Intent.Message.Image)
_sym_db.RegisterMessage(Intent.Message.QuickReplies)
_sym_db.RegisterMessage(Intent.Message.Card)
_sym_db.RegisterMessage(Intent.Message.Card.Button)
_sym_db.RegisterMessage(Intent.Message.SimpleResponse)
_sym_db.RegisterMessage(Intent.Message.SimpleResponses)
_sym_db.RegisterMessage(Intent.Message.BasicCard)
_sym_db.RegisterMessage(Intent.Message.BasicCard.Button)
_sym_db.RegisterMessage(Intent.Message.BasicCard.Button.OpenUriAction)
_sym_db.RegisterMessage(Intent.Message.Suggestion)
_sym_db.RegisterMessage(Intent.Message.Suggestions)
_sym_db.RegisterMessage(Intent.Message.LinkOutSuggestion)
_sym_db.RegisterMessage(Intent.Message.ListSelect)
_sym_db.RegisterMessage(Intent.Message.ListSelect.Item)
_sym_db.RegisterMessage(Intent.Message.CarouselSelect)
_sym_db.RegisterMessage(Intent.Message.CarouselSelect.Item)
_sym_db.RegisterMessage(Intent.Message.SelectItemInfo)
_sym_db.RegisterMessage(Intent.Message.TelephonyPlayAudio)
_sym_db.RegisterMessage(Intent.Message.TelephonySynthesizeSpeech)
_sym_db.RegisterMessage(Intent.Message.TelephonyTransferCall)
_sym_db.RegisterMessage(Intent.Message.RbmText)
_sym_db.RegisterMessage(Intent.Message.RbmCarouselCard)
_sym_db.RegisterMessage(Intent.Message.RbmStandaloneCard)
_sym_db.RegisterMessage(Intent.Message.RbmCardContent)
_sym_db.RegisterMessage(Intent.Message.RbmCardContent.RbmMedia)
_sym_db.RegisterMessage(Intent.Message.RbmSuggestion)
_sym_db.RegisterMessage(Intent.Message.RbmSuggestedReply)
_sym_db.RegisterMessage(Intent.Message.RbmSuggestedAction)
_sym_db.RegisterMessage(Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial)
_sym_db.RegisterMessage(Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri)
_sym_db.RegisterMessage(
    Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
)
_sym_db.RegisterMessage(Intent.Message.MediaContent)
_sym_db.RegisterMessage(Intent.Message.MediaContent.ResponseMediaObject)
_sym_db.RegisterMessage(Intent.Message.BrowseCarouselCard)
_sym_db.RegisterMessage(Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem)
_sym_db.RegisterMessage(
    Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
)
_sym_db.RegisterMessage(Intent.Message.TableCard)
_sym_db.RegisterMessage(Intent.Message.ColumnProperties)
_sym_db.RegisterMessage(Intent.Message.TableCardRow)
_sym_db.RegisterMessage(Intent.Message.TableCardCell)
_sym_db.RegisterMessage(Intent.FollowupIntentInfo)

ListIntentsRequest = _reflection.GeneratedProtocolMessageType(
    "ListIntentsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTINTENTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The request message for [Intents.ListIntents][google.cloud.dialogflow.
  v2beta1.Intents.ListIntents].
  
  Attributes:
      parent:
          Required. The agent to list all intents from. Format:
          ``projects/<Project ID>/agent``.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      intent_view:
          Optional. The resource view to apply to the returned intent.
      page_size:
          Optional. The maximum number of items to return in a single
          page. By default 100 and at most 1000.
      page_token:
          Optional. The next_page_token value returned from a previous
          list request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListIntentsRequest)
    },
)
_sym_db.RegisterMessage(ListIntentsRequest)

ListIntentsResponse = _reflection.GeneratedProtocolMessageType(
    "ListIntentsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTINTENTSRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The response message for [Intents.ListIntents][google.cloud.dialogflow
  .v2beta1.Intents.ListIntents].
  
  Attributes:
      intents:
          The list of agent intents. There will be a maximum number of
          items returned based on the page_size field in the request.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListIntentsResponse)
    },
)
_sym_db.RegisterMessage(ListIntentsResponse)

GetIntentRequest = _reflection.GeneratedProtocolMessageType(
    "GetIntentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETINTENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The request message for [Intents.GetIntent][google.cloud.dialogflow.v2
  beta1.Intents.GetIntent].
  
  Attributes:
      name:
          Required. The name of the intent. Format: ``projects/<Project
          ID>/agent/intents/<Intent ID>``.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      intent_view:
          Optional. The resource view to apply to the returned intent.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.GetIntentRequest)
    },
)
_sym_db.RegisterMessage(GetIntentRequest)

CreateIntentRequest = _reflection.GeneratedProtocolMessageType(
    "CreateIntentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEINTENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The request message for [Intents.CreateIntent][google.cloud.dialogflow
  .v2beta1.Intents.CreateIntent].
  
  Attributes:
      parent:
          Required. The agent to create a intent for. Format:
          ``projects/<Project ID>/agent``.
      intent:
          Required. The intent to create.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      intent_view:
          Optional. The resource view to apply to the returned intent.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.CreateIntentRequest)
    },
)
_sym_db.RegisterMessage(CreateIntentRequest)

UpdateIntentRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateIntentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEINTENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The request message for [Intents.UpdateIntent][google.cloud.dialogflow
  .v2beta1.Intents.UpdateIntent].
  
  Attributes:
      intent:
          Required. The intent to update.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      update_mask:
          Optional. The mask to control which fields get updated.
      intent_view:
          Optional. The resource view to apply to the returned intent.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.UpdateIntentRequest)
    },
)
_sym_db.RegisterMessage(UpdateIntentRequest)

DeleteIntentRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteIntentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEINTENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The request message for [Intents.DeleteIntent][google.cloud.dialogflow
  .v2beta1.Intents.DeleteIntent].
  
  Attributes:
      name:
          Required. The name of the intent to delete. If this intent has
          direct or indirect followup intents, we also delete them.
          Format: ``projects/<Project ID>/agent/intents/<Intent ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteIntentRequest)
    },
)
_sym_db.RegisterMessage(DeleteIntentRequest)

BatchUpdateIntentsRequest = _reflection.GeneratedProtocolMessageType(
    "BatchUpdateIntentsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHUPDATEINTENTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The request message for [Intents.BatchUpdateIntents][google.cloud.dial
  ogflow.v2beta1.Intents.BatchUpdateIntents].
  
  Attributes:
      parent:
          Required. The name of the agent to update or create intents
          in. Format: ``projects/<Project ID>/agent``.
      intent_batch:
          Required. The source of the intent batch.  For each intent in
          the batch:  -  If ``name`` is specified, we update an existing
          intent. -  If ``name`` is not specified, we create a new
          intent.
      intent_batch_uri:
          The URI to a Google Cloud Storage file containing intents to
          update or create. The file format can either be a serialized
          proto (of IntentBatch type) or JSON object. Note: The URI must
          start with “gs://”.
      intent_batch_inline:
          The collection of intents to update or create.
      language_code:
          Optional. The language used to access language-specific data.
          If not specified, the agent’s default language is used. For
          more information, see `Multilingual intent and entity data
          <https://cloud.google.com/dialogflow/docs/agents-
          multilingual#intent-entity>`__.
      update_mask:
          Optional. The mask to control which fields get updated.
      intent_view:
          Optional. The resource view to apply to the returned intent.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest)
    },
)
_sym_db.RegisterMessage(BatchUpdateIntentsRequest)

BatchUpdateIntentsResponse = _reflection.GeneratedProtocolMessageType(
    "BatchUpdateIntentsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHUPDATEINTENTSRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The response message for [Intents.BatchUpdateIntents][google.cloud.dia
  logflow.v2beta1.Intents.BatchUpdateIntents].
  
  Attributes:
      intents:
          The collection of updated or created intents.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse)
    },
)
_sym_db.RegisterMessage(BatchUpdateIntentsResponse)

BatchDeleteIntentsRequest = _reflection.GeneratedProtocolMessageType(
    "BatchDeleteIntentsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHDELETEINTENTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """The request message for [Intents.BatchDeleteIntents][google.cloud.dial
  ogflow.v2beta1.Intents.BatchDeleteIntents].
  
  Attributes:
      parent:
          Required. The name of the agent to delete all entities types
          for. Format: ``projects/<Project ID>/agent``.
      intents:
          Required. The collection of intents to delete. Only intent
          ``name`` must be filled in.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest)
    },
)
_sym_db.RegisterMessage(BatchDeleteIntentsRequest)

IntentBatch = _reflection.GeneratedProtocolMessageType(
    "IntentBatch",
    (_message.Message,),
    {
        "DESCRIPTOR": _INTENTBATCH,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.intent_pb2",
        "__doc__": """This message is a wrapper around a collection of intents.
  
  Attributes:
      intents:
          A collection of intents.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.IntentBatch)
    },
)
_sym_db.RegisterMessage(IntentBatch)


DESCRIPTOR._options = None
_INTENT_TRAININGPHRASE_TYPE.values_by_name["TEMPLATE"]._options = None
_INTENT_TRAININGPHRASE.fields_by_name["type"]._options = None
_INTENT_TRAININGPHRASE.fields_by_name["parts"]._options = None
_INTENT_TRAININGPHRASE.fields_by_name["times_added_count"]._options = None
_INTENT_MESSAGE_LISTSELECT.fields_by_name["subtitle"]._options = None
_INTENT_MESSAGE.fields_by_name["platform"]._options = None
_INTENT.fields_by_name["name"]._options = None
_INTENT.fields_by_name["display_name"]._options = None
_INTENT.fields_by_name["webhook_state"]._options = None
_INTENT.fields_by_name["priority"]._options = None
_INTENT.fields_by_name["is_fallback"]._options = None
_INTENT.fields_by_name["ml_enabled"]._options = None
_INTENT.fields_by_name["ml_disabled"]._options = None
_INTENT.fields_by_name["end_interaction"]._options = None
_INTENT.fields_by_name["input_context_names"]._options = None
_INTENT.fields_by_name["events"]._options = None
_INTENT.fields_by_name["training_phrases"]._options = None
_INTENT.fields_by_name["action"]._options = None
_INTENT.fields_by_name["output_contexts"]._options = None
_INTENT.fields_by_name["reset_contexts"]._options = None
_INTENT.fields_by_name["parameters"]._options = None
_INTENT.fields_by_name["default_response_platforms"]._options = None
_INTENT.fields_by_name["root_followup_intent_name"]._options = None
_INTENT.fields_by_name["parent_followup_intent_name"]._options = None
_INTENT.fields_by_name["followup_intent_info"]._options = None
_INTENT._options = None
_LISTINTENTSREQUEST.fields_by_name["parent"]._options = None
_LISTINTENTSREQUEST.fields_by_name["language_code"]._options = None
_GETINTENTREQUEST.fields_by_name["name"]._options = None
_GETINTENTREQUEST.fields_by_name["language_code"]._options = None
_CREATEINTENTREQUEST.fields_by_name["parent"]._options = None
_CREATEINTENTREQUEST.fields_by_name["intent"]._options = None
_CREATEINTENTREQUEST.fields_by_name["language_code"]._options = None
_UPDATEINTENTREQUEST.fields_by_name["intent"]._options = None
_UPDATEINTENTREQUEST.fields_by_name["language_code"]._options = None
_DELETEINTENTREQUEST.fields_by_name["name"]._options = None
_BATCHUPDATEINTENTSREQUEST.fields_by_name["parent"]._options = None
_BATCHUPDATEINTENTSREQUEST.fields_by_name["language_code"]._options = None
_BATCHDELETEINTENTSREQUEST.fields_by_name["parent"]._options = None
_BATCHDELETEINTENTSREQUEST.fields_by_name["intents"]._options = None

_INTENTS = _descriptor.ServiceDescriptor(
    name="Intents",
    full_name="google.cloud.dialogflow.v2beta1.Intents",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=12354,
    serialized_end=14501,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListIntents",
            full_name="google.cloud.dialogflow.v2beta1.Intents.ListIntents",
            index=0,
            containing_service=None,
            input_type=_LISTINTENTSREQUEST,
            output_type=_LISTINTENTSRESPONSE,
            serialized_options=b"\202\323\344\223\002f\022*/v2beta1/{parent=projects/*/agent}/intentsZ8\0226/v2beta1/{parent=projects/*/locations/*/agent}/intents\332A\006parent\332A\024parent,language_code",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetIntent",
            full_name="google.cloud.dialogflow.v2beta1.Intents.GetIntent",
            index=1,
            containing_service=None,
            input_type=_GETINTENTREQUEST,
            output_type=_INTENT,
            serialized_options=b"\202\323\344\223\002f\022*/v2beta1/{name=projects/*/agent/intents/*}Z8\0226/v2beta1/{name=projects/*/locations/*/agent/intents/*}\332A\004name\332A\022name,language_code",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateIntent",
            full_name="google.cloud.dialogflow.v2beta1.Intents.CreateIntent",
            index=2,
            containing_service=None,
            input_type=_CREATEINTENTREQUEST,
            output_type=_INTENT,
            serialized_options=b'\202\323\344\223\002v"*/v2beta1/{parent=projects/*/agent}/intents:\006intentZ@"6/v2beta1/{parent=projects/*/locations/*/agent}/intents:\006intent\332A\rparent,intent\332A\033parent,intent,language_code',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateIntent",
            full_name="google.cloud.dialogflow.v2beta1.Intents.UpdateIntent",
            index=3,
            containing_service=None,
            input_type=_UPDATEINTENTREQUEST,
            output_type=_INTENT,
            serialized_options=b"\202\323\344\223\002\204\00121/v2beta1/{intent.name=projects/*/agent/intents/*}:\006intentZG2=/v2beta1/{intent.name=projects/*/locations/*/agent/intents/*}:\006intent\332A\022intent,update_mask\332A\006intent\332A\024intent,language_code\332A intent,language_code,update_mask",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteIntent",
            full_name="google.cloud.dialogflow.v2beta1.Intents.DeleteIntent",
            index=4,
            containing_service=None,
            input_type=_DELETEINTENTREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002f**/v2beta1/{name=projects/*/agent/intents/*}Z8*6/v2beta1/{name=projects/*/locations/*/agent/intents/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchUpdateIntents",
            full_name="google.cloud.dialogflow.v2beta1.Intents.BatchUpdateIntents",
            index=5,
            containing_service=None,
            input_type=_BATCHUPDATEINTENTSREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\204\001"6/v2beta1/{parent=projects/*/agent}/intents:batchUpdate:\001*ZG"B/v2beta1/{parent=projects/*/locations/*/agent}/intents:batchUpdate:\001*\312AT\n:google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchDeleteIntents",
            full_name="google.cloud.dialogflow.v2beta1.Intents.BatchDeleteIntents",
            index=6,
            containing_service=None,
            input_type=_BATCHDELETEINTENTSREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002\204\001"6/v2beta1/{parent=projects/*/agent}/intents:batchDelete:\001*ZG"B/v2beta1/{parent=projects/*/locations/*/agent}/intents:batchDelete:\001*\332A\016parent,intents\312A/\n\025google.protobuf.Empty\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_INTENTS)

DESCRIPTOR.services_by_name["Intents"] = _INTENTS

# @@protoc_insertion_point(module_scope)
